# This file is generated by objective.metadata
#
# Last update: Mon Mar 16 08:52:15 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
misc.update(
    {
        "CFXMLEntityInfo": objc.createStructType(
            "CFXMLEntityInfo",
            sel32or64(
                b"{_CFXMLEntityInfo=l^{__CFString=}{_CFXMLExternalID=^{__CFURL=}^{__CFString=}}^{__CFString=}}",
                b"{_CFXMLEntityInfo=q^{__CFString=}{_CFXMLExternalID=^{__CFURL=}^{__CFString=}}^{__CFString=}}",
            ),
            ["entityType", "replacementText", "entityID", "notationName"],
        ),
        "CFXMLElementInfo": objc.createStructType(
            "CFXMLElementInfo",
            b"{_CFXMLElementInfo=^{__CFDictionary=}^{__CFArray=}Z[3c]}",
            ["attributes", "attributeOrder", "isEmpty", "_reserved"],
        ),
        "CFXMLAttributeListDeclarationInfo": objc.createStructType(
            "CFXMLAttributeListDeclarationInfo",
            sel32or64(
                b"{_CFXMLAttributeListDeclarationInfo=l^{_CFXMLAttributeDeclarationInfo=^{__CFString=}^{__CFString=}^{__CFString=}}}",
                b"{_CFXMLAttributeListDeclarationInfo=q^{_CFXMLAttributeDeclarationInfo=^{__CFString=}^{__CFString=}^{__CFString=}}}",
            ),
            ["numberOfAttributes", "attributes"],
        ),
        "CFXMLElementTypeDeclarationInfo": objc.createStructType(
            "CFXMLElementTypeDeclarationInfo",
            b"{_CFXMLElementTypeDeclarationInfo=^{__CFString=}}",
            ["contentDescription"],
        ),
        "CFGregorianDate": objc.createStructType(
            "CFGregorianDate",
            sel32or64(b"{_CFGregorianDate=lccccd}", b"{_CFGregorianDate=iccccd}"),
            ["year", "month", "day", "hour", "minute", "second"],
        ),
        "CFXMLExternalID": objc.createStructType(
            "CFXMLExternalID",
            b"{_CFXMLExternalID=^{__CFURL=}^{__CFString=}}",
            ["systemID", "publicID"],
        ),
        "CFUUIDBytes": objc.createStructType(
            "CFUUIDBytes",
            b"{_CFUUIDBytes=CCCCCCCCCCCCCCCC}",
            [
                "byte0",
                "byte1",
                "byte2",
                "byte3",
                "byte4",
                "byte5",
                "byte6",
                "byte7",
                "byte8",
                "byte9",
                "byte10",
                "byte11",
                "byte12",
                "byte13",
                "byte14",
                "byte15",
            ],
        ),
        "CFXMLAttributeDeclarationInfo": objc.createStructType(
            "CFXMLAttributeDeclarationInfo",
            b"{_CFXMLAttributeDeclarationInfo=^{__CFString=}^{__CFString=}^{__CFString=}}",
            ["attributeName", "typeString", "defaultString"],
        ),
        "CFSwappedFloat32": objc.createStructType(
            "CFSwappedFloat32", b"{_CFSwappedFloat32=I}", ["v"]
        ),
        "CFSwappedFloat64": objc.createStructType(
            "CFSwappedFloat64", b"{_CFSwappedFloat64=Q}", ["v"]
        ),
        "CFXMLDocumentTypeInfo": objc.createStructType(
            "CFXMLDocumentTypeInfo",
            b"{_CFXMLDocumentTypeInfo={_CFXMLExternalID=^{__CFURL=}^{__CFString=}}}",
            ["externalID"],
        ),
        "CFStreamError": objc.createStructType(
            "CFStreamError",
            sel32or64(b"{_CFStreamError=ll}", b"{_CFStreamError=qi}"),
            ["domain", "error"],
        ),
        "CFXMLEntityReferenceInfo": objc.createStructType(
            "CFXMLEntityReferenceInfo",
            sel32or64(
                b"{_CFXMLEntityReferenceInfo=l}", b"{_CFXMLEntityReferenceInfo=q}"
            ),
            ["entityType"],
        ),
        "CFXMLProcessingInstructionInfo": objc.createStructType(
            "CFXMLProcessingInstructionInfo",
            b"{_CFXMLProcessingInstructionInfo=^{__CFString=}}",
            ["dataString"],
        ),
        "CFRange": objc.createStructType(
            "CFRange",
            sel32or64(b"{_CFRange=ll}", b"{_CFRange=qq}"),
            ["location", "length"],
        ),
        "CFSocketSignature": objc.createStructType(
            "CFSocketSignature",
            sel32or64(
                b"{_CFSocketSignature=lll^{__CFData=}}",
                b"{_CFSocketSignature=iii^{__CFData=}}",
            ),
            ["protocolFamily", "socketType", "protocol", "address"],
        ),
        "CFXMLDocumentInfo": objc.createStructType(
            "CFXMLDocumentInfo",
            sel32or64(
                b"{_CFXMLDocumentInfo=^{__CFURL=}L}",
                b"{_CFXMLDocumentInfo=^{__CFURL=}I}",
            ),
            ["sourceURL", "encoding"],
        ),
        "CFGregorianUnits": objc.createStructType(
            "CFGregorianUnits",
            sel32or64(b"{_CFGregorianUnits=llllld}", b"{_CFGregorianUnits=iiiiid}"),
            ["years", "months", "days", "hours", "minutes", "seconds"],
        ),
        "CFXMLNotationInfo": objc.createStructType(
            "CFXMLNotationInfo",
            b"{_CFXMLNotationInfo={_CFXMLExternalID=^{__CFURL=}^{__CFString=}}}",
            ["externalID"],
        ),
    }
)
constants = """$kCFAbsoluteTimeIntervalSince1904@d$kCFAbsoluteTimeIntervalSince1970@d$kCFAllocatorDefault@^{__CFAllocator=}$kCFAllocatorMalloc@^{__CFAllocator=}$kCFAllocatorMallocZone@^{__CFAllocator=}$kCFAllocatorNull@^{__CFAllocator=}$kCFAllocatorSystemDefault@^{__CFAllocator=}$kCFAllocatorUseContext@^{__CFAllocator=}$kCFBooleanFalse@^{__CFBoolean=}$kCFBooleanTrue@^{__CFBoolean=}$kCFBuddhistCalendar@^{__CFString=}$kCFBundleDevelopmentRegionKey@^{__CFString=}$kCFBundleExecutableKey@^{__CFString=}$kCFBundleIdentifierKey@^{__CFString=}$kCFBundleInfoDictionaryVersionKey@^{__CFString=}$kCFBundleLocalizationsKey@^{__CFString=}$kCFBundleNameKey@^{__CFString=}$kCFBundleVersionKey@^{__CFString=}$kCFChineseCalendar@^{__CFString=}$kCFCoreFoundationVersionNumber@d$kCFDateFormatterAMSymbol@^{__CFString=}$kCFDateFormatterCalendar@^{__CFString=}$kCFDateFormatterCalendarName@^{__CFString=}$kCFDateFormatterDefaultDate@^{__CFString=}$kCFDateFormatterDefaultFormat@^{__CFString=}$kCFDateFormatterDoesRelativeDateFormattingKey@^{__CFString=}$kCFDateFormatterEraSymbols@^{__CFString=}$kCFDateFormatterGregorianStartDate@^{__CFString=}$kCFDateFormatterIsLenient@^{__CFString=}$kCFDateFormatterLongEraSymbols@^{__CFString=}$kCFDateFormatterMonthSymbols@^{__CFString=}$kCFDateFormatterPMSymbol@^{__CFString=}$kCFDateFormatterQuarterSymbols@^{__CFString=}$kCFDateFormatterShortMonthSymbols@^{__CFString=}$kCFDateFormatterShortQuarterSymbols@^{__CFString=}$kCFDateFormatterShortStandaloneMonthSymbols@^{__CFString=}$kCFDateFormatterShortStandaloneQuarterSymbols@^{__CFString=}$kCFDateFormatterShortStandaloneWeekdaySymbols@^{__CFString=}$kCFDateFormatterShortWeekdaySymbols@^{__CFString=}$kCFDateFormatterStandaloneMonthSymbols@^{__CFString=}$kCFDateFormatterStandaloneQuarterSymbols@^{__CFString=}$kCFDateFormatterStandaloneWeekdaySymbols@^{__CFString=}$kCFDateFormatterTimeZone@^{__CFString=}$kCFDateFormatterTwoDigitStartDate@^{__CFString=}$kCFDateFormatterVeryShortMonthSymbols@^{__CFString=}$kCFDateFormatterVeryShortStandaloneMonthSymbols@^{__CFString=}$kCFDateFormatterVeryShortStandaloneWeekdaySymbols@^{__CFString=}$kCFDateFormatterVeryShortWeekdaySymbols@^{__CFString=}$kCFDateFormatterWeekdaySymbols@^{__CFString=}$kCFErrorDescriptionKey@^{__CFString=}$kCFErrorDomainCocoa@^{__CFString=}$kCFErrorDomainMach@^{__CFString=}$kCFErrorDomainOSStatus@^{__CFString=}$kCFErrorDomainPOSIX@^{__CFString=}$kCFErrorFilePathKey@^{__CFString=}$kCFErrorLocalizedDescriptionKey@^{__CFString=}$kCFErrorLocalizedFailureKey@^{__CFString=}$kCFErrorLocalizedFailureReasonKey@^{__CFString=}$kCFErrorLocalizedRecoverySuggestionKey@^{__CFString=}$kCFErrorURLKey@^{__CFString=}$kCFErrorUnderlyingErrorKey@^{__CFString=}$kCFGregorianCalendar@^{__CFString=}$kCFHebrewCalendar@^{__CFString=}$kCFISO8601Calendar@^{__CFString=}$kCFIndianCalendar@^{__CFString=}$kCFIslamicCalendar@^{__CFString=}$kCFIslamicCivilCalendar@^{__CFString=}$kCFIslamicTabularCalendar@^{__CFString=}$kCFIslamicUmmAlQuraCalendar@^{__CFString=}$kCFJapaneseCalendar@^{__CFString=}$kCFLocaleAlternateQuotationBeginDelimiterKey@^{__CFString=}$kCFLocaleAlternateQuotationEndDelimiterKey@^{__CFString=}$kCFLocaleCalendar@^{__CFString=}$kCFLocaleCalendarIdentifier@^{__CFString=}$kCFLocaleCollationIdentifier@^{__CFString=}$kCFLocaleCollatorIdentifier@^{__CFString=}$kCFLocaleCountryCode@^{__CFString=}$kCFLocaleCountryCodeKey$kCFLocaleCurrencyCode@^{__CFString=}$kCFLocaleCurrencySymbol@^{__CFString=}$kCFLocaleCurrentLocaleDidChangeNotification@^{__CFString=}$kCFLocaleDecimalSeparator@^{__CFString=}$kCFLocaleExemplarCharacterSet@^{__CFString=}$kCFLocaleGroupingSeparator@^{__CFString=}$kCFLocaleIdentifier@^{__CFString=}$kCFLocaleLanguageCode@^{__CFString=}$kCFLocaleLanguageCodeKey$kCFLocaleMeasurementSystem@^{__CFString=}$kCFLocaleQuotationBeginDelimiterKey@^{__CFString=}$kCFLocaleQuotationEndDelimiterKey@^{__CFString=}$kCFLocaleScriptCode@^{__CFString=}$kCFLocaleUsesMetricSystem@^{__CFString=}$kCFLocaleVariantCode@^{__CFString=}$kCFNull@^{__CFNull=}$kCFNumberFormatterAlwaysShowDecimalSeparator@^{__CFString=}$kCFNumberFormatterCurrencyCode@^{__CFString=}$kCFNumberFormatterCurrencyDecimalSeparator@^{__CFString=}$kCFNumberFormatterCurrencyGroupingSeparator@^{__CFString=}$kCFNumberFormatterCurrencySymbol@^{__CFString=}$kCFNumberFormatterDecimalSeparator@^{__CFString=}$kCFNumberFormatterDefaultFormat@^{__CFString=}$kCFNumberFormatterExponentSymbol@^{__CFString=}$kCFNumberFormatterFormatWidth@^{__CFString=}$kCFNumberFormatterGroupingSeparator@^{__CFString=}$kCFNumberFormatterGroupingSize@^{__CFString=}$kCFNumberFormatterInfinitySymbol@^{__CFString=}$kCFNumberFormatterInternationalCurrencySymbol@^{__CFString=}$kCFNumberFormatterIsLenient@^{__CFString=}$kCFNumberFormatterMaxFractionDigits@^{__CFString=}$kCFNumberFormatterMaxIntegerDigits@^{__CFString=}$kCFNumberFormatterMaxSignificantDigits@^{__CFString=}$kCFNumberFormatterMinFractionDigits@^{__CFString=}$kCFNumberFormatterMinIntegerDigits@^{__CFString=}$kCFNumberFormatterMinSignificantDigits@^{__CFString=}$kCFNumberFormatterMinusSign@^{__CFString=}$kCFNumberFormatterMultiplier@^{__CFString=}$kCFNumberFormatterNaNSymbol@^{__CFString=}$kCFNumberFormatterNegativePrefix@^{__CFString=}$kCFNumberFormatterNegativeSuffix@^{__CFString=}$kCFNumberFormatterPaddingCharacter@^{__CFString=}$kCFNumberFormatterPaddingPosition@^{__CFString=}$kCFNumberFormatterPerMillSymbol@^{__CFString=}$kCFNumberFormatterPercentSymbol@^{__CFString=}$kCFNumberFormatterPlusSign@^{__CFString=}$kCFNumberFormatterPositivePrefix@^{__CFString=}$kCFNumberFormatterPositiveSuffix@^{__CFString=}$kCFNumberFormatterRoundingIncrement@^{__CFString=}$kCFNumberFormatterRoundingMode@^{__CFString=}$kCFNumberFormatterSecondaryGroupingSize@^{__CFString=}$kCFNumberFormatterUseGroupingSeparator@^{__CFString=}$kCFNumberFormatterUseSignificantDigits@^{__CFString=}$kCFNumberFormatterZeroSymbol@^{__CFString=}$kCFNumberNaN@^{__CFNumber=}$kCFNumberNegativeInfinity@^{__CFNumber=}$kCFNumberPositiveInfinity@^{__CFNumber=}$kCFPersianCalendar@^{__CFString=}$kCFPreferencesAnyApplication@^{__CFString=}$kCFPreferencesAnyHost@^{__CFString=}$kCFPreferencesAnyUser@^{__CFString=}$kCFPreferencesCurrentApplication@^{__CFString=}$kCFPreferencesCurrentHost@^{__CFString=}$kCFPreferencesCurrentUser@^{__CFString=}$kCFRepublicOfChinaCalendar@^{__CFString=}$kCFRunLoopCommonModes@^{__CFString=}$kCFRunLoopDefaultMode@^{__CFString=}$kCFSocketCommandKey@^{__CFString=}$kCFSocketErrorKey@^{__CFString=}$kCFSocketNameKey@^{__CFString=}$kCFSocketRegisterCommand@^{__CFString=}$kCFSocketResultKey@^{__CFString=}$kCFSocketRetrieveCommand@^{__CFString=}$kCFSocketValueKey@^{__CFString=}$kCFStreamErrorDomainSOCKS@i$kCFStreamErrorDomainSSL@i$kCFStreamPropertyAppendToFile@^{__CFString=}$kCFStreamPropertyDataWritten@^{__CFString=}$kCFStreamPropertyFileCurrentOffset@^{__CFString=}$kCFStreamPropertySOCKSPassword@^{__CFString=}$kCFStreamPropertySOCKSProxy@^{__CFString=}$kCFStreamPropertySOCKSProxyHost@^{__CFString=}$kCFStreamPropertySOCKSProxyPort@^{__CFString=}$kCFStreamPropertySOCKSUser@^{__CFString=}$kCFStreamPropertySOCKSVersion@^{__CFString=}$kCFStreamPropertyShouldCloseNativeSocket@^{__CFString=}$kCFStreamPropertySocketNativeHandle@^{__CFString=}$kCFStreamPropertySocketRemoteHostName@^{__CFString=}$kCFStreamPropertySocketRemotePortNumber@^{__CFString=}$kCFStreamPropertySocketSecurityLevel@^{__CFString=}$kCFStreamSocketSOCKSVersion4@^{__CFString=}$kCFStreamSocketSOCKSVersion5@^{__CFString=}$kCFStreamSocketSecurityLevelNegotiatedSSL@^{__CFString=}$kCFStreamSocketSecurityLevelNone@^{__CFString=}$kCFStreamSocketSecurityLevelSSLv2@^{__CFString=}$kCFStreamSocketSecurityLevelSSLv3@^{__CFString=}$kCFStreamSocketSecurityLevelTLSv1@^{__CFString=}$kCFStringTransformFullwidthHalfwidth@^{__CFString=}$kCFStringTransformHiraganaKatakana@^{__CFString=}$kCFStringTransformLatinArabic@^{__CFString=}$kCFStringTransformLatinCyrillic@^{__CFString=}$kCFStringTransformLatinGreek@^{__CFString=}$kCFStringTransformLatinHangul@^{__CFString=}$kCFStringTransformLatinHebrew@^{__CFString=}$kCFStringTransformLatinHiragana@^{__CFString=}$kCFStringTransformLatinKatakana@^{__CFString=}$kCFStringTransformLatinThai@^{__CFString=}$kCFStringTransformMandarinLatin@^{__CFString=}$kCFStringTransformStripCombiningMarks@^{__CFString=}$kCFStringTransformStripDiacritics@^{__CFString=}$kCFStringTransformToLatin@^{__CFString=}$kCFStringTransformToUnicodeName@^{__CFString=}$kCFStringTransformToXMLHex@^{__CFString=}$kCFTimeZoneSystemTimeZoneDidChangeNotification@^{__CFString=}$kCFURLAddedToDirectoryDateKey@^{__CFString=}$kCFURLApplicationIsScriptableKey@^{__CFString=}$kCFURLAttributeModificationDateKey@^{__CFString=}$kCFURLCanonicalPathKey@^{__CFString=}$kCFURLContentAccessDateKey@^{__CFString=}$kCFURLContentModificationDateKey@^{__CFString=}$kCFURLCreationDateKey@^{__CFString=}$kCFURLCustomIconKey@^{__CFString=}$kCFURLDocumentIdentifierKey@^{__CFString=}$kCFURLEffectiveIconKey@^{__CFString=}$kCFURLFileAllocatedSizeKey@^{__CFString=}$kCFURLFileDirectoryContents@^{__CFString=}$kCFURLFileExists@^{__CFString=}$kCFURLFileLastModificationTime@^{__CFString=}$kCFURLFileLength@^{__CFString=}$kCFURLFileOwnerID@^{__CFString=}$kCFURLFilePOSIXMode@^{__CFString=}$kCFURLFileProtectionComplete@^{__CFString=}$kCFURLFileProtectionCompleteUnlessOpen@^{__CFString=}$kCFURLFileProtectionCompleteUntilFirstUserAuthentication@^{__CFString=}$kCFURLFileProtectionKey@^{__CFString=}$kCFURLFileProtectionNone@^{__CFString=}$kCFURLFileResourceIdentifierKey@^{__CFString=}$kCFURLFileResourceTypeBlockSpecial@^{__CFString=}$kCFURLFileResourceTypeCharacterSpecial@^{__CFString=}$kCFURLFileResourceTypeDirectory@^{__CFString=}$kCFURLFileResourceTypeKey@^{__CFString=}$kCFURLFileResourceTypeNamedPipe@^{__CFString=}$kCFURLFileResourceTypeRegular@^{__CFString=}$kCFURLFileResourceTypeSocket@^{__CFString=}$kCFURLFileResourceTypeSymbolicLink@^{__CFString=}$kCFURLFileResourceTypeUnknown@^{__CFString=}$kCFURLFileSecurityKey@^{__CFString=}$kCFURLFileSizeKey@^{__CFString=}$kCFURLGenerationIdentifierKey@^{__CFString=}$kCFURLHTTPStatusCode@^{__CFString=}$kCFURLHTTPStatusLine@^{__CFString=}$kCFURLHasHiddenExtensionKey@^{__CFString=}$kCFURLIsAliasFileKey@^{__CFString=}$kCFURLIsApplicationKey@^{__CFString=}$kCFURLIsDirectoryKey@^{__CFString=}$kCFURLIsExcludedFromBackupKey@^{__CFString=}$kCFURLIsExecutableKey@^{__CFString=}$kCFURLIsHiddenKey@^{__CFString=}$kCFURLIsMountTriggerKey@^{__CFString=}$kCFURLIsPackageKey@^{__CFString=}$kCFURLIsReadableKey@^{__CFString=}$kCFURLIsRegularFileKey@^{__CFString=}$kCFURLIsSymbolicLinkKey@^{__CFString=}$kCFURLIsSystemImmutableKey@^{__CFString=}$kCFURLIsUbiquitousItemKey@^{__CFString=}$kCFURLIsUserImmutableKey@^{__CFString=}$kCFURLIsVolumeKey@^{__CFString=}$kCFURLIsWritableKey@^{__CFString=}$kCFURLKeysOfUnsetValuesKey@^{__CFString=}$kCFURLLabelColorKey@^{__CFString=}$kCFURLLabelNumberKey@^{__CFString=}$kCFURLLinkCountKey@^{__CFString=}$kCFURLLocalizedLabelKey@^{__CFString=}$kCFURLLocalizedNameKey@^{__CFString=}$kCFURLLocalizedTypeDescriptionKey@^{__CFString=}$kCFURLNameKey@^{__CFString=}$kCFURLParentDirectoryURLKey@^{__CFString=}$kCFURLPathKey@^{__CFString=}$kCFURLPreferredIOBlockSizeKey@^{__CFString=}$kCFURLQuarantinePropertiesKey@^{__CFString=}$kCFURLTagNamesKey@^{__CFString=}$kCFURLTotalFileAllocatedSizeKey@^{__CFString=}$kCFURLTotalFileSizeKey@^{__CFString=}$kCFURLTypeIdentifierKey@^{__CFString=}$kCFURLUbiquitousItemDownloadingErrorKey@^{__CFString=}$kCFURLUbiquitousItemDownloadingStatusCurrent@^{__CFString=}$kCFURLUbiquitousItemDownloadingStatusDownloaded@^{__CFString=}$kCFURLUbiquitousItemDownloadingStatusKey@^{__CFString=}$kCFURLUbiquitousItemDownloadingStatusNotDownloaded@^{__CFString=}$kCFURLUbiquitousItemHasUnresolvedConflictsKey@^{__CFString=}$kCFURLUbiquitousItemIsDownloadedKey@^{__CFString=}$kCFURLUbiquitousItemIsDownloadingKey@^{__CFString=}$kCFURLUbiquitousItemIsUploadedKey@^{__CFString=}$kCFURLUbiquitousItemIsUploadingKey@^{__CFString=}$kCFURLUbiquitousItemPercentDownloadedKey@^{__CFString=}$kCFURLUbiquitousItemPercentUploadedKey@^{__CFString=}$kCFURLUbiquitousItemUploadingErrorKey@^{__CFString=}$kCFURLVolumeAvailableCapacityForImportantUsageKey@^{__CFString=}$kCFURLVolumeAvailableCapacityForOpportunisticUsageKey@^{__CFString=}$kCFURLVolumeAvailableCapacityKey@^{__CFString=}$kCFURLVolumeCreationDateKey@^{__CFString=}$kCFURLVolumeIdentifierKey@^{__CFString=}$kCFURLVolumeIsAutomountedKey@^{__CFString=}$kCFURLVolumeIsBrowsableKey@^{__CFString=}$kCFURLVolumeIsEjectableKey@^{__CFString=}$kCFURLVolumeIsEncryptedKey@^{__CFString=}$kCFURLVolumeIsInternalKey@^{__CFString=}$kCFURLVolumeIsJournalingKey@^{__CFString=}$kCFURLVolumeIsLocalKey@^{__CFString=}$kCFURLVolumeIsReadOnlyKey@^{__CFString=}$kCFURLVolumeIsRemovableKey@^{__CFString=}$kCFURLVolumeIsRootFileSystemKey@^{__CFString=}$kCFURLVolumeLocalizedFormatDescriptionKey@^{__CFString=}$kCFURLVolumeLocalizedNameKey@^{__CFString=}$kCFURLVolumeMaximumFileSizeKey@^{__CFString=}$kCFURLVolumeNameKey@^{__CFString=}$kCFURLVolumeResourceCountKey@^{__CFString=}$kCFURLVolumeSupportsAccessPermissionsKey@^{__CFString=}$kCFURLVolumeSupportsAdvisoryFileLockingKey@^{__CFString=}$kCFURLVolumeSupportsCasePreservedNamesKey@^{__CFString=}$kCFURLVolumeSupportsCaseSensitiveNamesKey@^{__CFString=}$kCFURLVolumeSupportsCompressionKey@^{__CFString=}$kCFURLVolumeSupportsExclusiveRenamingKey@^{__CFString=}$kCFURLVolumeSupportsExtendedSecurityKey@^{__CFString=}$kCFURLVolumeSupportsFileCloningKey@^{__CFString=}$kCFURLVolumeSupportsHardLinksKey@^{__CFString=}$kCFURLVolumeSupportsImmutableFilesKey@^{__CFString=}$kCFURLVolumeSupportsJournalingKey@^{__CFString=}$kCFURLVolumeSupportsPersistentIDsKey@^{__CFString=}$kCFURLVolumeSupportsRenamingKey@^{__CFString=}$kCFURLVolumeSupportsRootDirectoryDatesKey@^{__CFString=}$kCFURLVolumeSupportsSparseFilesKey@^{__CFString=}$kCFURLVolumeSupportsSwapRenamingKey@^{__CFString=}$kCFURLVolumeSupportsSymbolicLinksKey@^{__CFString=}$kCFURLVolumeSupportsVolumeSizesKey@^{__CFString=}$kCFURLVolumeSupportsZeroRunsKey@^{__CFString=}$kCFURLVolumeTotalCapacityKey@^{__CFString=}$kCFURLVolumeURLForRemountingKey@^{__CFString=}$kCFURLVolumeURLKey@^{__CFString=}$kCFURLVolumeUUIDStringKey@^{__CFString=}$kCFUserNotificationAlertHeaderKey@^{__CFString=}$kCFUserNotificationAlertMessageKey@^{__CFString=}$kCFUserNotificationAlertTopMostKey@^{__CFString=}$kCFUserNotificationAlternateButtonTitleKey@^{__CFString=}$kCFUserNotificationCheckBoxTitlesKey@^{__CFString=}$kCFUserNotificationDefaultButtonTitleKey@^{__CFString=}$kCFUserNotificationIconURLKey@^{__CFString=}$kCFUserNotificationKeyboardTypesKey@^{__CFString=}$kCFUserNotificationLocalizationURLKey@^{__CFString=}$kCFUserNotificationOtherButtonTitleKey@^{__CFString=}$kCFUserNotificationPopUpSelectionKey@^{__CFString=}$kCFUserNotificationPopUpTitlesKey@^{__CFString=}$kCFUserNotificationProgressIndicatorValueKey@^{__CFString=}$kCFUserNotificationSoundURLKey@^{__CFString=}$kCFUserNotificationTextFieldTitlesKey@^{__CFString=}$kCFUserNotificationTextFieldValuesKey@^{__CFString=}$kCFXMLTreeErrorDescription@^{__CFString=}$kCFXMLTreeErrorLineNumber@^{__CFString=}$kCFXMLTreeErrorLocation@^{__CFString=}$kCFXMLTreeErrorStatusCode@^{__CFString=}$"""
enums = """$CFByteOrderBigEndian@2$CFByteOrderLittleEndian@1$CFByteOrderUnknown@0$CFNotificationSuspensionBehaviorCoalesce@2$CFNotificationSuspensionBehaviorDeliverImmediately@4$CFNotificationSuspensionBehaviorDrop@1$CFNotificationSuspensionBehaviorHold@3$CF_USE_OSBYTEORDER_H@1$COREFOUNDATION_CFPLUGINCOM_SEPARATE@1$FALSE@0$TRUE@1$kCFBookmarkResolutionWithoutMountingMask@512$kCFBookmarkResolutionWithoutUIMask@256$kCFBundleExecutableArchitectureI386@7$kCFBundleExecutableArchitecturePPC@18$kCFBundleExecutableArchitecturePPC64@16777234$kCFBundleExecutableArchitectureX86_64@16777223$kCFCalendarComponentsWrap@1$kCFCalendarUnitDay@16$kCFCalendarUnitEra@2$kCFCalendarUnitHour@32$kCFCalendarUnitMinute@64$kCFCalendarUnitMonth@8$kCFCalendarUnitQuarter@2048$kCFCalendarUnitSecond@128$kCFCalendarUnitWeek@256$kCFCalendarUnitWeekOfMonth@4096$kCFCalendarUnitWeekOfYear@8192$kCFCalendarUnitWeekday@512$kCFCalendarUnitWeekdayOrdinal@1024$kCFCalendarUnitYear@4$kCFCalendarUnitYearForWeekOfYear@16384$kCFCharacterSetAlphaNumeric@10$kCFCharacterSetCapitalizedLetter@13$kCFCharacterSetControl@1$kCFCharacterSetDecimalDigit@4$kCFCharacterSetDecomposable@9$kCFCharacterSetIllegal@12$kCFCharacterSetLetter@5$kCFCharacterSetLowercaseLetter@6$kCFCharacterSetNewline@15$kCFCharacterSetNonBase@8$kCFCharacterSetPunctuation@11$kCFCharacterSetSymbol@14$kCFCharacterSetUppercaseLetter@7$kCFCharacterSetWhitespace@2$kCFCharacterSetWhitespaceAndNewline@3$kCFCompareAnchored@8$kCFCompareBackwards@4$kCFCompareCaseInsensitive@1$kCFCompareDiacriticInsensitive@128$kCFCompareEqualTo@0$kCFCompareForcedOrdering@512$kCFCompareGreaterThan@1$kCFCompareLessThan@-1$kCFCompareLocalized@32$kCFCompareNonliteral@16$kCFCompareNumerically@64$kCFCompareWidthInsensitive@256$kCFCoreFoundationVersionNumber10_10@1151.16$kCFCoreFoundationVersionNumber10_10_1@1151.16$kCFCoreFoundationVersionNumber10_10_2@1152$kCFCoreFoundationVersionNumber10_10_3@1153.18$kCFCoreFoundationVersionNumber10_10_4@1153.18$kCFCoreFoundationVersionNumber10_10_5@1153.18$kCFCoreFoundationVersionNumber10_10_Max@1199$kCFCoreFoundationVersionNumber10_11@1253$kCFCoreFoundationVersionNumber10_11_1@1255.1$kCFCoreFoundationVersionNumber10_11_2@1256.14$kCFCoreFoundationVersionNumber10_11_3@1256.14$kCFCoreFoundationVersionNumber10_11_4@1258.1$kCFCoreFoundationVersionNumber10_11_Max@1299$kCFDataSearchAnchored@2$kCFDataSearchBackwards@1$kCFDateFormatterFullStyle@4$kCFDateFormatterLongStyle@3$kCFDateFormatterMediumStyle@2$kCFDateFormatterNoStyle@0$kCFDateFormatterShortStyle@1$kCFFileDescriptorReadCallBack@1$kCFFileDescriptorWriteCallBack@2$kCFFileSecurityClearAccessControlList@32$kCFFileSecurityClearGroup@2$kCFFileSecurityClearGroupUUID@16$kCFFileSecurityClearMode@4$kCFFileSecurityClearOwner@1$kCFFileSecurityClearOwnerUUID@8$kCFGregorianAllUnits@16777215$kCFGregorianUnitsDays@4$kCFGregorianUnitsHours@8$kCFGregorianUnitsMinutes@16$kCFGregorianUnitsMonths@2$kCFGregorianUnitsSeconds@32$kCFGregorianUnitsYears@1$kCFISO8601DateFormatWithColonSeparatorInTime@512$kCFISO8601DateFormatWithColonSeparatorInTimeZone@1024$kCFISO8601DateFormatWithDashSeparatorInDate@256$kCFISO8601DateFormatWithDay@16$kCFISO8601DateFormatWithFractionalSeconds@2048$kCFISO8601DateFormatWithFullDate@275$kCFISO8601DateFormatWithFullTime@1632$kCFISO8601DateFormatWithInternetDateTime@1907$kCFISO8601DateFormatWithMonth@2$kCFISO8601DateFormatWithSpaceBetweenDateAndTime@128$kCFISO8601DateFormatWithTime@32$kCFISO8601DateFormatWithTimeZone@64$kCFISO8601DateFormatWithWeekOfYear@4$kCFISO8601DateFormatWithYear@1$kCFLocaleLanguageDirectionBottomToTop@4$kCFLocaleLanguageDirectionLeftToRight@1$kCFLocaleLanguageDirectionRightToLeft@2$kCFLocaleLanguageDirectionTopToBottom@3$kCFLocaleLanguageDirectionUnknown@0$kCFMessagePortBecameInvalidError@-5$kCFMessagePortIsInvalid@-3$kCFMessagePortReceiveTimeout@-2$kCFMessagePortSendTimeout@-1$kCFMessagePortSuccess@0$kCFMessagePortTransportError@-4$kCFNotFound@-1$kCFNotificationDeliverImmediately@1$kCFNotificationPostToAllSessions@2$kCFNumberCFIndexType@14$kCFNumberCGFloatType@16$kCFNumberCharType@7$kCFNumberDoubleType@13$kCFNumberFloat32Type@5$kCFNumberFloat64Type@6$kCFNumberFloatType@12$kCFNumberFormatterCurrencyAccountingStyle@10$kCFNumberFormatterCurrencyISOCodeStyle@8$kCFNumberFormatterCurrencyPluralStyle@9$kCFNumberFormatterCurrencyStyle@2$kCFNumberFormatterDecimalStyle@1$kCFNumberFormatterNoStyle@0$kCFNumberFormatterOrdinalStyle@6$kCFNumberFormatterPadAfterPrefix@1$kCFNumberFormatterPadAfterSuffix@3$kCFNumberFormatterPadBeforePrefix@0$kCFNumberFormatterPadBeforeSuffix@2$kCFNumberFormatterParseIntegersOnly@1$kCFNumberFormatterPercentStyle@3$kCFNumberFormatterRoundCeiling@0$kCFNumberFormatterRoundDown@2$kCFNumberFormatterRoundFloor@1$kCFNumberFormatterRoundHalfDown@5$kCFNumberFormatterRoundHalfEven@4$kCFNumberFormatterRoundHalfUp@6$kCFNumberFormatterRoundUp@3$kCFNumberFormatterScientificStyle@4$kCFNumberFormatterSpellOutStyle@5$kCFNumberIntType@9$kCFNumberLongLongType@11$kCFNumberLongType@10$kCFNumberMaxType@16$kCFNumberNSIntegerType@15$kCFNumberSInt16Type@2$kCFNumberSInt32Type@3$kCFNumberSInt64Type@4$kCFNumberSInt8Type@1$kCFNumberShortType@8$kCFPropertyListBinaryFormat_v1_0@200$kCFPropertyListImmutable@0$kCFPropertyListMutableContainers@1$kCFPropertyListMutableContainersAndLeaves@2$kCFPropertyListOpenStepFormat@1$kCFPropertyListReadCorruptError@3840$kCFPropertyListReadStreamError@3842$kCFPropertyListReadUnknownVersionError@3841$kCFPropertyListWriteStreamError@3851$kCFPropertyListXMLFormat_v1_0@100$kCFRunLoopAfterWaiting@64$kCFRunLoopAllActivities@268435455$kCFRunLoopBeforeSources@4$kCFRunLoopBeforeTimers@2$kCFRunLoopBeforeWaiting@32$kCFRunLoopEntry@1$kCFRunLoopExit@128$kCFRunLoopRunFinished@1$kCFRunLoopRunHandledSource@4$kCFRunLoopRunStopped@2$kCFRunLoopRunTimedOut@3$kCFSocketAcceptCallBack@2$kCFSocketAutomaticallyReenableAcceptCallBack@2$kCFSocketAutomaticallyReenableDataCallBack@3$kCFSocketAutomaticallyReenableReadCallBack@1$kCFSocketAutomaticallyReenableWriteCallBack@8$kCFSocketCloseOnInvalidate@128$kCFSocketConnectCallBack@4$kCFSocketDataCallBack@3$kCFSocketError@-1$kCFSocketLeaveErrors@64$kCFSocketNoCallBack@0$kCFSocketReadCallBack@1$kCFSocketSuccess@0$kCFSocketTimeout@-2$kCFSocketWriteCallBack@8$kCFStreamErrorDomainCustom@-1$kCFStreamErrorDomainMacOSStatus@2$kCFStreamErrorDomainPOSIX@1$kCFStreamEventCanAcceptBytes@4$kCFStreamEventEndEncountered@16$kCFStreamEventErrorOccurred@8$kCFStreamEventHasBytesAvailable@2$kCFStreamEventNone@0$kCFStreamEventOpenCompleted@1$kCFStreamStatusAtEnd@5$kCFStreamStatusClosed@6$kCFStreamStatusError@7$kCFStreamStatusNotOpen@0$kCFStreamStatusOpen@2$kCFStreamStatusOpening@1$kCFStreamStatusReading@3$kCFStreamStatusWriting@4$kCFStringEncodingANSEL@1537$kCFStringEncodingASCII@1536$kCFStringEncodingBig5@2563$kCFStringEncodingBig5_E@2569$kCFStringEncodingBig5_HKSCS_1999@2566$kCFStringEncodingCNS_11643_92_P1@1617$kCFStringEncodingCNS_11643_92_P2@1618$kCFStringEncodingCNS_11643_92_P3@1619$kCFStringEncodingDOSArabic@1049$kCFStringEncodingDOSBalticRim@1030$kCFStringEncodingDOSCanadianFrench@1048$kCFStringEncodingDOSChineseSimplif@1057$kCFStringEncodingDOSChineseTrad@1059$kCFStringEncodingDOSCyrillic@1043$kCFStringEncodingDOSGreek@1029$kCFStringEncodingDOSGreek1@1041$kCFStringEncodingDOSGreek2@1052$kCFStringEncodingDOSHebrew@1047$kCFStringEncodingDOSIcelandic@1046$kCFStringEncodingDOSJapanese@1056$kCFStringEncodingDOSKorean@1058$kCFStringEncodingDOSLatin1@1040$kCFStringEncodingDOSLatin2@1042$kCFStringEncodingDOSLatinUS@1024$kCFStringEncodingDOSNordic@1050$kCFStringEncodingDOSPortuguese@1045$kCFStringEncodingDOSRussian@1051$kCFStringEncodingDOSThai@1053$kCFStringEncodingDOSTurkish@1044$kCFStringEncodingEBCDIC_CP037@3074$kCFStringEncodingEBCDIC_US@3073$kCFStringEncodingEUC_CN@2352$kCFStringEncodingEUC_JP@2336$kCFStringEncodingEUC_KR@2368$kCFStringEncodingEUC_TW@2353$kCFStringEncodingGBK_95@1585$kCFStringEncodingGB_18030_2000@1586$kCFStringEncodingGB_2312_80@1584$kCFStringEncodingHZ_GB_2312@2565$kCFStringEncodingISOLatin1@513$kCFStringEncodingISOLatin10@528$kCFStringEncodingISOLatin2@514$kCFStringEncodingISOLatin3@515$kCFStringEncodingISOLatin4@516$kCFStringEncodingISOLatin5@521$kCFStringEncodingISOLatin6@522$kCFStringEncodingISOLatin7@525$kCFStringEncodingISOLatin8@526$kCFStringEncodingISOLatin9@527$kCFStringEncodingISOLatinArabic@518$kCFStringEncodingISOLatinCyrillic@517$kCFStringEncodingISOLatinGreek@519$kCFStringEncodingISOLatinHebrew@520$kCFStringEncodingISOLatinThai@523$kCFStringEncodingISO_2022_CN@2096$kCFStringEncodingISO_2022_CN_EXT@2097$kCFStringEncodingISO_2022_JP@2080$kCFStringEncodingISO_2022_JP_1@2082$kCFStringEncodingISO_2022_JP_2@2081$kCFStringEncodingISO_2022_JP_3@2083$kCFStringEncodingISO_2022_KR@2112$kCFStringEncodingInvalidId@4294967295$kCFStringEncodingJIS_C6226_78@1572$kCFStringEncodingJIS_X0201_76@1568$kCFStringEncodingJIS_X0208_83@1569$kCFStringEncodingJIS_X0208_90@1570$kCFStringEncodingJIS_X0212_90@1571$kCFStringEncodingKOI8_R@2562$kCFStringEncodingKOI8_U@2568$kCFStringEncodingKSC_5601_87@1600$kCFStringEncodingKSC_5601_92_Johab@1601$kCFStringEncodingMacArabic@4$kCFStringEncodingMacArmenian@24$kCFStringEncodingMacBengali@13$kCFStringEncodingMacBurmese@19$kCFStringEncodingMacCeltic@39$kCFStringEncodingMacCentralEurRoman@29$kCFStringEncodingMacChineseSimp@25$kCFStringEncodingMacChineseTrad@2$kCFStringEncodingMacCroatian@36$kCFStringEncodingMacCyrillic@7$kCFStringEncodingMacDevanagari@9$kCFStringEncodingMacDingbats@34$kCFStringEncodingMacEthiopic@28$kCFStringEncodingMacExtArabic@31$kCFStringEncodingMacFarsi@140$kCFStringEncodingMacGaelic@40$kCFStringEncodingMacGeorgian@23$kCFStringEncodingMacGreek@6$kCFStringEncodingMacGujarati@11$kCFStringEncodingMacGurmukhi@10$kCFStringEncodingMacHFS@255$kCFStringEncodingMacHebrew@5$kCFStringEncodingMacIcelandic@37$kCFStringEncodingMacInuit@236$kCFStringEncodingMacJapanese@1$kCFStringEncodingMacKannada@16$kCFStringEncodingMacKhmer@20$kCFStringEncodingMacKorean@3$kCFStringEncodingMacLaotian@22$kCFStringEncodingMacMalayalam@17$kCFStringEncodingMacMongolian@27$kCFStringEncodingMacOriya@12$kCFStringEncodingMacRoman@0$kCFStringEncodingMacRomanLatin1@2564$kCFStringEncodingMacRomanian@38$kCFStringEncodingMacSinhalese@18$kCFStringEncodingMacSymbol@33$kCFStringEncodingMacTamil@14$kCFStringEncodingMacTelugu@15$kCFStringEncodingMacThai@21$kCFStringEncodingMacTibetan@26$kCFStringEncodingMacTurkish@35$kCFStringEncodingMacUkrainian@152$kCFStringEncodingMacVT100@252$kCFStringEncodingMacVietnamese@30$kCFStringEncodingNextStepJapanese@2818$kCFStringEncodingNextStepLatin@2817$kCFStringEncodingNonLossyASCII@3071$kCFStringEncodingShiftJIS@2561$kCFStringEncodingShiftJIS_X0213@1576$kCFStringEncodingShiftJIS_X0213_00@1576$kCFStringEncodingShiftJIS_X0213_MenKuTen@1577$kCFStringEncodingUTF16@256$kCFStringEncodingUTF16BE@268435712$kCFStringEncodingUTF16LE@335544576$kCFStringEncodingUTF32@201326848$kCFStringEncodingUTF32BE@402653440$kCFStringEncodingUTF32LE@469762304$kCFStringEncodingUTF7@67109120$kCFStringEncodingUTF7_IMAP@2576$kCFStringEncodingUTF8@134217984$kCFStringEncodingUnicode@256$kCFStringEncodingVISCII@2567$kCFStringEncodingWindowsArabic@1286$kCFStringEncodingWindowsBalticRim@1287$kCFStringEncodingWindowsCyrillic@1282$kCFStringEncodingWindowsGreek@1283$kCFStringEncodingWindowsHebrew@1285$kCFStringEncodingWindowsKoreanJohab@1296$kCFStringEncodingWindowsLatin1@1280$kCFStringEncodingWindowsLatin2@1281$kCFStringEncodingWindowsLatin5@1284$kCFStringEncodingWindowsVietnamese@1288$kCFStringNormalizationFormC@2$kCFStringNormalizationFormD@0$kCFStringNormalizationFormKC@3$kCFStringNormalizationFormKD@1$kCFStringTokenizerAttributeLanguage@131072$kCFStringTokenizerAttributeLatinTranscription@65536$kCFStringTokenizerTokenHasDerivedSubTokensMask@4$kCFStringTokenizerTokenHasHasNumbersMask@8$kCFStringTokenizerTokenHasNonLettersMask@16$kCFStringTokenizerTokenHasSubTokensMask@2$kCFStringTokenizerTokenIsCJWordMask@32$kCFStringTokenizerTokenNone@0$kCFStringTokenizerTokenNormal@1$kCFStringTokenizerUnitLineBreak@3$kCFStringTokenizerUnitParagraph@2$kCFStringTokenizerUnitSentence@1$kCFStringTokenizerUnitWord@0$kCFStringTokenizerUnitWordBoundary@4$kCFTimeZoneNameStyleDaylightSaving@2$kCFTimeZoneNameStyleGeneric@4$kCFTimeZoneNameStyleShortDaylightSaving@3$kCFTimeZoneNameStyleShortGeneric@5$kCFTimeZoneNameStyleShortStandard@1$kCFTimeZoneNameStyleStandard@0$kCFURLBookmarkCreationMinimalBookmarkMask@512$kCFURLBookmarkCreationPreferFileIDResolutionMask@256$kCFURLBookmarkCreationSecurityScopeAllowOnlyReadAccess@4096$kCFURLBookmarkCreationSuitableForBookmarkFile@1024$kCFURLBookmarkCreationWithSecurityScope@2048$kCFURLBookmarkResolutionWithSecurityScope@1024$kCFURLBookmarkResolutionWithoutMountingMask@512$kCFURLBookmarkResolutionWithoutUIMask@256$kCFURLComponentFragment@12$kCFURLComponentHost@8$kCFURLComponentNetLocation@2$kCFURLComponentParameterString@10$kCFURLComponentPassword@6$kCFURLComponentPath@3$kCFURLComponentPort@9$kCFURLComponentQuery@11$kCFURLComponentResourceSpecifier@4$kCFURLComponentScheme@1$kCFURLComponentUser@5$kCFURLComponentUserInfo@7$kCFURLEnumeratorDefaultBehavior@0$kCFURLEnumeratorDescendRecursively@1$kCFURLEnumeratorDirectoryPostOrderSuccess@4$kCFURLEnumeratorEnd@2$kCFURLEnumeratorError@3$kCFURLEnumeratorGenerateFileReferenceURLs@4$kCFURLEnumeratorGenerateRelativePathURLs@64$kCFURLEnumeratorIncludeDirectoriesPostOrder@32$kCFURLEnumeratorIncludeDirectoriesPreOrder@16$kCFURLEnumeratorSkipInvisibles@2$kCFURLEnumeratorSkipPackageContents@8$kCFURLEnumeratorSuccess@1$kCFURLHFSPathStyle@1$kCFURLImproperArgumentsError@-15$kCFURLPOSIXPathStyle@0$kCFURLPropertyKeyUnavailableError@-17$kCFURLRemoteHostUnavailableError@-14$kCFURLResourceAccessViolationError@-13$kCFURLResourceNotFoundError@-12$kCFURLTimeoutError@-18$kCFURLUnknownError@-10$kCFURLUnknownPropertyKeyError@-16$kCFURLUnknownSchemeError@-11$kCFURLWindowsPathStyle@2$kCFUserNotificationAlternateResponse@1$kCFUserNotificationCancelResponse@3$kCFUserNotificationCautionAlertLevel@2$kCFUserNotificationDefaultResponse@0$kCFUserNotificationNoDefaultButtonFlag@32$kCFUserNotificationNoteAlertLevel@1$kCFUserNotificationOtherResponse@2$kCFUserNotificationPlainAlertLevel@3$kCFUserNotificationStopAlertLevel@0$kCFUserNotificationUseRadioButtonsFlag@64$kCFXMLEntityTypeCharacter@4$kCFXMLEntityTypeParameter@0$kCFXMLEntityTypeParsedExternal@2$kCFXMLEntityTypeParsedInternal@1$kCFXMLEntityTypeUnparsed@3$kCFXMLErrorElementlessDocument@11$kCFXMLErrorEncodingConversionFailure@3$kCFXMLErrorMalformedCDSect@7$kCFXMLErrorMalformedCharacterReference@13$kCFXMLErrorMalformedCloseTag@8$kCFXMLErrorMalformedComment@12$kCFXMLErrorMalformedDTD@5$kCFXMLErrorMalformedDocument@10$kCFXMLErrorMalformedName@6$kCFXMLErrorMalformedParsedCharacterData@14$kCFXMLErrorMalformedProcessingInstruction@4$kCFXMLErrorMalformedStartTag@9$kCFXMLErrorNoData@15$kCFXMLErrorUnexpectedEOF@1$kCFXMLErrorUnknownEncoding@2$kCFXMLNodeCurrentVersion@1$kCFXMLNodeTypeAttribute@3$kCFXMLNodeTypeAttributeListDeclaration@15$kCFXMLNodeTypeCDATASection@7$kCFXMLNodeTypeComment@5$kCFXMLNodeTypeDocument@1$kCFXMLNodeTypeDocumentFragment@8$kCFXMLNodeTypeDocumentType@11$kCFXMLNodeTypeElement@2$kCFXMLNodeTypeElementTypeDeclaration@14$kCFXMLNodeTypeEntity@9$kCFXMLNodeTypeEntityReference@10$kCFXMLNodeTypeNotation@13$kCFXMLNodeTypeProcessingInstruction@4$kCFXMLNodeTypeText@6$kCFXMLNodeTypeWhitespace@12$kCFXMLParserAddImpliedAttributes@32$kCFXMLParserAllOptions@16777215$kCFXMLParserNoOptions@0$kCFXMLParserReplacePhysicalEntities@4$kCFXMLParserResolveExternalEntities@16$kCFXMLParserSkipMetaData@2$kCFXMLParserSkipWhitespace@8$kCFXMLParserValidateDocument@1$kCFXMLStatusParseInProgress@-1$kCFXMLStatusParseNotBegun@-2$kCFXMLStatusParseSuccessful@0$"""
misc.update(
    {
        "kCFCoreFoundationVersionNumber10_7_1": 635.0,
        "kCFCoreFoundationVersionNumber10_4_4_Intel": 368.26,
        "kCFCoreFoundationVersionNumber10_11_4": 1258.1,
        "kCFCoreFoundationVersionNumber10_11_3": 1256.14,
        "kCFCoreFoundationVersionNumber10_11_2": 1256.14,
        "kCFCoreFoundationVersionNumber10_11_1": 1255.1,
        "kCFCoreFoundationVersionNumber10_10_4": 1153.18,
        "kCFCoreFoundationVersionNumber10_10_5": 1153.18,
        "kCFCoreFoundationVersionNumber10_10_3": 1153.18,
        "kCFCoreFoundationVersionNumber10_10_1": 1151.16,
        "kCFCoreFoundationVersionNumber10_8_2": 744.12,
        "kCFCoreFoundationVersionNumber10_8_3": 744.18,
        "kCFCoreFoundationVersionNumber10_8_1": 744.0,
        "kCFCoreFoundationVersionNumber10_5_1": 476.0,
        "kCFCoreFoundationVersionNumber10_8_4": 744.19,
        "kCFCoreFoundationVersionNumber10_9_2": 855.14,
        "kCFCoreFoundationVersionNumber10_9_1": 855.11,
        "kCFCoreFoundationVersionNumber10_4_7": 368.27,
        "kCFCoreFoundationVersionNumber10_4_4_PowerPC": 368.25,
        "kCFCoreFoundationVersionNumber10_4_2": 368.11,
        "kCFCoreFoundationVersionNumber10_4_3": 368.18,
        "kCFCoreFoundationVersionNumber10_4_1": 368.1,
        "kCFCoreFoundationVersionNumber10_5_7": 476.18,
        "kCFCoreFoundationVersionNumber10_5_6": 476.17,
        "kCFCoreFoundationVersionNumber10_5_5": 476.15,
        "kCFCoreFoundationVersionNumber10_5_4": 476.14,
        "kCFCoreFoundationVersionNumber10_5_3": 476.13,
        "kCFCoreFoundationVersionNumber10_5_2": 476.1,
        "kCFCoreFoundationVersionNumber10_4_8": 368.27,
        "kCFCoreFoundationVersionNumber10_4_9": 368.28,
        "kCFCoreFoundationVersionNumber10_2_4": 263.3,
        "kCFCoreFoundationVersionNumber10_2_5": 263.5,
        "kCFCoreFoundationVersionNumber10_2_6": 263.5,
        "kCFCoreFoundationVersionNumber10_2_7": 263.5,
        "kCFCoreFoundationVersionNumber10_3_9": 299.35,
        "kCFCoreFoundationVersionNumber10_2_1": 263.1,
        "kCFCoreFoundationVersionNumber10_2_2": 263.1,
        "kCFCoreFoundationVersionNumber10_2_3": 263.3,
        "kCFCoreFoundationVersionNumber10_3_5": 299.31,
        "kCFCoreFoundationVersionNumber10_3_4": 299.31,
        "kCFCoreFoundationVersionNumber10_3_7": 299.33,
        "kCFCoreFoundationVersionNumber10_3_6": 299.32,
        "kCFCoreFoundationVersionNumber10_3_1": 299.0,
        "kCFCoreFoundationVersionNumber10_3_3": 299.3,
        "kCFCoreFoundationVersionNumber10_3_2": 299.0,
        "kCFCoreFoundationVersionNumber10_1_3": 227.2,
        "kCFCoreFoundationVersionNumber10_1_2": 227.2,
        "kCFCoreFoundationVersionNumber10_1_1": 226.0,
        "kCFCoreFoundationVersionNumber10_1_4": 227.3,
        "kCFCoreFoundationVersionNumber10_4_6_PowerPC": 368.25,
        "kCFCoreFoundationVersionNumber10_6_2": 550.13,
        "kCFCoreFoundationVersionNumber10_6_3": 550.19,
        "kCFCoreFoundationVersionNumber10_6_4": 550.29,
        "kCFCoreFoundationVersionNumber10_6_5": 550.42,
        "kCFCoreFoundationVersionNumber10_6_6": 550.42,
        "kCFCoreFoundationVersionNumber10_6_7": 550.42,
        "kCFCoreFoundationVersionNumber10_6_8": 550.43,
        "kCFCoreFoundationVersionNumber10_0_3": 196.5,
        "kCFCoreFoundationVersionNumber10_7_3": 635.19,
        "kCFCoreFoundationVersionNumber10_7_2": 635.15,
        "kCFCoreFoundationVersionNumber10_4_10": 368.28,
        "kCFCoreFoundationVersionNumber10_7_4": 635.21,
        "kCFCoreFoundationVersionNumber10_4_5_PowerPC": 368.25,
        "kCFCoreFoundationVersionNumber10_3_8": 299.33,
        "kCFCoreFoundationVersionNumber10_10": 1151.16,
        "kCFCoreFoundationVersionNumber10_4_5_Intel": 368.26,
        "kCFCoreFoundationVersionNumber10_2_8": 263.5,
        "kCFCoreFoundationVersionNumber10_5_8": 476.19,
        "kCFCoreFoundationVersionNumber10_4_11": 368.31,
        "kCFCoreFoundationVersionNumber10_6_1": 550.0,
        "kCFCoreFoundationVersionNumber10_8": 744.0,
        "kCFCoreFoundationVersionNumber10_5": 476.0,
        "kCFCoreFoundationVersionNumber10_4": 368.0,
        "kCFCoreFoundationVersionNumber10_7": 635.0,
        "kCFCoreFoundationVersionNumber10_6": 550.0,
        "kCFCoreFoundationVersionNumber10_1": 226.0,
        "kCFCoreFoundationVersionNumber10_0": 196.4,
        "kCFCoreFoundationVersionNumber10_3": 299.0,
        "kCFCoreFoundationVersionNumber10_2": 263.0,
        "kCFCoreFoundationVersionNumber10_7_5": 635.21,
        "kCFCoreFoundationVersionNumber10_9": 855.11,
        "kCFCoreFoundationVersionNumber10_4_6_Intel": 368.26,
    }
)
functions = {
    "CFURLCreateByResolvingBookmarkData": (
        sel32or64(
            b"^{__CFURL=}^{__CFAllocator=}^{__CFData=}L^{__CFURL=}^{__CFArray=}^Z^^{__CFError=}",
            b"^{__CFURL=}^{__CFAllocator=}^{__CFData=}Q^{__CFURL=}^{__CFArray=}^Z^^{__CFError=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                5: {"type_modifier": "o"},
                6: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
            },
        },
    ),
    "CFConvertDoubleSwappedToHost": (b"d{_CFSwappedFloat64=Q}",),
    "CFURLCreateCopyAppendingPathComponent": (
        b"^{__CFURL=}^{__CFAllocator=}^{__CFURL=}^{__CFString=}Z",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRangeMake": (sel32or64(b"{_CFRange=ll}ll", b"{_CFRange=qq}qq"),),
    "CFBitVectorGetCount": (sel32or64(b"l^{__CFBitVector=}", b"q^{__CFBitVector=}"),),
    "CFDictionaryContainsKey": (b"Z^{__CFDictionary=}@",),
    "CFPreferencesCopyValue": (
        b"@^{__CFString=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFGetAllocator": (b"^{__CFAllocator=}@",),
    "CFSetCreateMutable": (
        sel32or64(
            b"^{__CFSet=}^{__CFAllocator=}l^{_CFSetCallBacks=l^?^?^?^?^?}",
            b"^{__CFSet=}^{__CFAllocator=}q^{_CFSetCallBacks=q^?^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFErrorGetCode": (sel32or64(b"l^{__CFError=}", b"q^{__CFError=}"),),
    "CFStringGetFileSystemRepresentation": (
        sel32or64(b"Z^{__CFString=}^tl", b"Z^{__CFString=}^tq"),
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "o"}}},
    ),
    "CFLocaleGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFUUIDGetUUIDBytes": (b"{_CFUUIDBytes=CCCCCCCCCCCCCCCC}^{__CFUUID=}",),
    "CFDateFormatterCreateDateFormatFromTemplate": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^{__CFString=}L^{__CFLocale=}",
            b"^{__CFString=}^{__CFAllocator=}^{__CFString=}Q^{__CFLocale=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFTreeInsertSibling": (b"v^{__CFTree=}^{__CFTree=}",),
    "CFSocketConnectToAddress": (
        sel32or64(b"l^{__CFSocket=}^{__CFData=}d", b"q^{__CFSocket=}^{__CFData=}d"),
    ),
    "CFWriteStreamScheduleWithRunLoop": (
        b"v^{__CFWriteStream=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "CFDateFormatterCreateStringWithAbsoluteTime": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFDateFormatter=}d",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFReadStreamScheduleWithRunLoop": (
        b"v^{__CFReadStream=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "CFArrayAppendValue": (b"v^{__CFArray=}@",),
    "CFSetRemoveValue": (b"v^{__CFSet=}@",),
    "CFBundleCopyPrivateFrameworksURL": (
        b"^{__CFURL=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorCreateMutable": (
        sel32or64(
            b"^{__CFBitVector=}^{__CFAllocator=}l",
            b"^{__CFBitVector=}^{__CFAllocator=}q",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFLocaleCreateCanonicalLocaleIdentifierFromString": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringTokenizerCopyBestStringLanguage": (
        sel32or64(
            b"^{__CFString=}^{__CFString=}{_CFRange=ll}",
            b"^{__CFString=}^{__CFString=}{_CFRange=qq}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFUUIDCreate": (
        b"^{__CFUUID=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCalendarGetRangeOfUnit": (
        sel32or64(
            b"{_CFRange=ll}^{__CFCalendar=}LLd", b"{_CFRange=qq}^{__CFCalendar=}QQd"
        ),
    ),
    "CFStringFindWithOptionsAndLocale": (
        sel32or64(
            b"Z^{__CFString=}^{__CFString=}{_CFRange=ll}L^{__CFLocale=}^{_CFRange=ll}",
            b"Z^{__CFString=}^{__CFString=}{_CFRange=qq}Q^{__CFLocale=}^{_CFRange=qq}",
        ),
        "",
        {"arguments": {5: {"type_modifier": "o"}}},
    ),
    "CFURLSetResourcePropertyForKey": (
        b"Z^{__CFURL=}^{__CFString=}@^^{__CFError=}",
        "",
        {
            "arguments": {
                3: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "CFFileSecurityCopyOwnerUUID": (
        b"Z^{__CFFileSecurity=}^^{__CFUUID=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "o"}},
        },
    ),
    "CFCalendarAddComponents": (
        sel32or64(b"Z^{__CFCalendar=}^dL^c", b"Z^{__CFCalendar=}^dQ^c"),
        "",
        {"variadic": True},
    ),
    "CFLocaleCopyCommonISOCurrencyCodes": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCalendarGetOrdinalityOfUnit": (
        sel32or64(b"l^{__CFCalendar=}LLd", b"q^{__CFCalendar=}QQd"),
    ),
    "CFPreferencesRemoveSuitePreferencesFromApp": (b"v^{__CFString=}^{__CFString=}",),
    "CFCalendarGetMinimumDaysInFirstWeek": (
        sel32or64(b"l^{__CFCalendar=}", b"q^{__CFCalendar=}"),
    ),
    "CFURLCreateWithFileSystemPathRelativeToBase": (
        sel32or64(
            b"^{__CFURL=}^{__CFAllocator=}^{__CFString=}lZ^{__CFURL=}",
            b"^{__CFURL=}^{__CFAllocator=}^{__CFString=}qZ^{__CFURL=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBinaryHeapGetCountOfValue": (
        sel32or64(b"l^{__CFBinaryHeap=}@", b"q^{__CFBinaryHeap=}@"),
    ),
    "CFStringIsSurrogateLowCharacter": (b"ZT",),
    "CFStringTrim": (b"v^{__CFString=}^{__CFString=}",),
    "CFXMLNodeGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFStringSetExternalCharactersNoCopy": (
        sel32or64(b"v^{__CFString=}^Tll", b"v^{__CFString=}^Tqq"),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 3, "type_modifier": "n"}},
        },
    ),
    "CFLocaleGetSystem": (b"^{__CFLocale=}",),
    "CFDataGetLength": (sel32or64(b"l^{__CFData=}", b"q^{__CFData=}"),),
    "CFWriteStreamWrite": (
        sel32or64(b"l^{__CFWriteStream=}^vl", b"q^{__CFWriteStream=}^vq"),
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}}},
    ),
    "CFBundleGetVersionNumber": (sel32or64(b"L^{__CFBundle=}", b"I^{__CFBundle=}"),),
    "CFGetRetainCount": (sel32or64(b"l@", b"q@"),),
    "CFRunLoopObserverGetContext": (
        sel32or64(
            b"v^{__CFRunLoopObserver=}^{_CFRunLoopObserverContext=l^v^?^?^?}",
            b"v^{__CFRunLoopObserver=}^{_CFRunLoopObserverContext=q^v^?^?^?}",
        ),
    ),
    "CFDataCreateWithBytesNoCopy": (
        sel32or64(
            b"^{__CFData=}^{__CFAllocator=}^vl^{__CFAllocator=}",
            b"^{__CFData=}^{__CFAllocator=}^vq^{__CFAllocator=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFURLEnumeratorGetNextURL": (
        sel32or64(
            b"l^{__CFURLEnumerator=}^^{__CFURL=}^^{__CFError=}",
            b"q^{__CFURLEnumerator=}^^{__CFURL=}^^{__CFError=}",
        ),
        "",
        {
            "arguments": {
                1: {"type_modifier": "o"},
                2: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
            }
        },
    ),
    "CFRunLoopTimerGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFStringConvertNSStringEncodingToEncoding": (sel32or64(b"LL", b"IQ"),),
    "CFURLCreateBookmarkDataFromFile": (
        b"^{__CFData=}^{__CFAllocator=}^{__CFURL=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "CFBundleCopyResourceURLForLocalization": (
        b"^{__CFURL=}^{__CFBundle=}^{__CFString=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringGetMaximumSizeForEncoding": (sel32or64(b"llL", b"qqI"),),
    "CFStringTransform": (
        sel32or64(
            b"Z^{__CFString=}^{_CFRange=ll}^{__CFString=}Z",
            b"Z^{__CFString=}^{_CFRange=qq}^{__CFString=}Z",
        ),
        "",
        {"arguments": {1: {"type_modifier": "N"}}},
    ),
    "CFURLStopAccessingSecurityScopedResource": (b"v^{__CFURL=}",),
    "CFDataCreateMutableCopy": (
        sel32or64(
            b"^{__CFData=}^{__CFAllocator=}l^{__CFData=}",
            b"^{__CFData=}^{__CFAllocator=}q^{__CFData=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFMachPortGetContext": (
        sel32or64(
            b"v^{__CFMachPort=}^{_CFMachPortContext=l^v^?^?^?}",
            b"v^{__CFMachPort=}^{_CFMachPortContext=q^v^?^?^?}",
        ),
    ),
    "CFDateFormatterGetDateStyle": (
        sel32or64(b"l^{__CFDateFormatter=}", b"q^{__CFDateFormatter=}"),
    ),
    "CFStringGetHyphenationLocationBeforeIndex": (
        sel32or64(
            b"l^{__CFString=}l{_CFRange=ll}L^{__CFLocale=}^L",
            b"q^{__CFString=}q{_CFRange=qq}Q^{__CFLocale=}^I",
        ),
        "",
        {"arguments": {5: {"type_modifier": "o"}}},
    ),
    "CFRunLoopIsWaiting": (b"Z^{__CFRunLoop=}",),
    "CFAttributedStringReplaceString": (
        sel32or64(
            b"v^{__CFAttributedString=}{_CFRange=ll}^{__CFString=}",
            b"v^{__CFAttributedString=}{_CFRange=qq}^{__CFString=}",
        ),
    ),
    "CFSocketCreateWithNative": (
        sel32or64(
            b"^{__CFSocket=}^{__CFAllocator=}iL^?^{_CFSocketContext=l^v^?^?^?}",
            b"^{__CFSocket=}^{__CFAllocator=}iQ^?^{_CFSocketContext=q^v^?^?^?}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFSocket=}"},
                            1: {"type": b"Q"},
                            2: {"type": b"^{__CFData=}"},
                            3: {"type": b"^v"},
                            4: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFMessagePortCreateLocal": (
        sel32or64(
            b"^{__CFMessagePort=}^{__CFAllocator=}^{__CFString=}^?^{_CFMessagePortContext=l^v^?^?^?}^Z",
            b"^{__CFMessagePort=}^{__CFAllocator=}^{__CFString=}^?^{_CFMessagePortContext=q^v^?^?^?}^Z",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"^{__CFData=}"},
                        "arguments": {
                            0: {"type": b"^{__CFMessagePort=}"},
                            1: {"type": b"i"},
                            2: {"type": b"^{__CFData=}"},
                            3: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFTimeZoneCopyDefault": (
        b"^{__CFTimeZone=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFArrayGetValueAtIndex": (sel32or64(b"@^{__CFArray=}l", b"@^{__CFArray=}q"),),
    "CFErrorCopyFailureReason": (
        b"^{__CFString=}^{__CFError=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBinaryHeapContainsValue": (b"Z^{__CFBinaryHeap=}@",),
    "CFNumberFormatterGetStyle": (
        sel32or64(b"l^{__CFNumberFormatter=}", b"q^{__CFNumberFormatter=}"),
    ),
    "CFXMLParserCreate": (
        sel32or64(
            b"^{__CFXMLParser=}^{__CFAllocator=}^{__CFData=}^{__CFURL=}Ll^{_CFXMLParserCallBacks=l^?^?^?^?^?}^{_CFXMLParserContext=l^v^?^?^?}",
            b"^{__CFXMLParser=}^{__CFAllocator=}^{__CFData=}^{__CFURL=}Qq^{_CFXMLParserCallBacks=q^?^?^?^?^?}^{_CFXMLParserContext=q^v^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFLocaleCopyPreferredLanguages": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBagCreateCopy": (
        b"^{__CFBag=}^{__CFAllocator=}^{__CFBag=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFNotificationCenterGetDistributedCenter": (b"^{__CFNotificationCenter=}",),
    "CFXMLTreeGetNode": (b"^{__CFXMLNode=}^{__CFTree=}",),
    "CFDateCreate": (
        b"^{__CFDate=}^{__CFAllocator=}d",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFErrorCopyDescription": (
        b"^{__CFString=}^{__CFError=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCharacterSetGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFWriteStreamCopyProperty": (
        b"@^{__CFWriteStream=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAttributedStringGetLength": (
        sel32or64(b"l^{__CFAttributedString=}", b"q^{__CFAttributedString=}"),
    ),
    "CFStringGetCStringPtr": (
        sel32or64(b"^t@L", b"^t@I"),
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "CFFileDescriptorEnableCallBacks": (
        sel32or64(b"v^{__CFFileDescriptor=}L", b"v^{__CFFileDescriptor=}Q"),
    ),
    "CFURLGetString": (b"^{__CFString=}^{__CFURL=}",),
    "CFReadStreamSetProperty": (b"Z^{__CFReadStream=}^{__CFString=}@",),
    "CFFileDescriptorInvalidate": (b"v^{__CFFileDescriptor=}",),
    "CFBagGetCountOfValue": (sel32or64(b"l^{__CFBag=}@", b"q^{__CFBag=}@"),),
    "CFAbsoluteTimeGetCurrent": (b"d",),
    "CFLocaleCopyISOCurrencyCodes": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCalendarGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFBundleCopySharedFrameworksURL": (
        b"^{__CFURL=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAttributedStringCreateWithSubstring": (
        sel32or64(
            b"^{__CFAttributedString=}^{__CFAllocator=}^{__CFAttributedString=}{_CFRange=ll}",
            b"^{__CFAttributedString=}^{__CFAllocator=}^{__CFAttributedString=}{_CFRange=qq}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringAppend": (b"v^{__CFString=}^{__CFString=}",),
    "CFRelease": (b"v@",),
    "CFAllocatorGetDefault": (b"^{__CFAllocator=}",),
    "CFStringTokenizerAdvanceToNextToken": (
        sel32or64(b"L^{__CFStringTokenizer=}", b"Q^{__CFStringTokenizer=}"),
    ),
    "CFAttributedStringGetAttributeAndLongestEffectiveRange": (
        sel32or64(
            b"@^{__CFAttributedString=}l^{__CFString=}{_CFRange=ll}^{_CFRange=ll}",
            b"@^{__CFAttributedString=}q^{__CFString=}{_CFRange=qq}^{_CFRange=qq}",
        ),
        "",
        {"arguments": {4: {"type_modifier": "o"}}},
    ),
    "CFFileDescriptorGetContext": (
        sel32or64(
            b"v^{__CFFileDescriptor=}^{_CFFileDescriptorContext=l^v^?^?^?}",
            b"v^{__CFFileDescriptor=}^{_CFFileDescriptorContext=q^v^?^?^?}",
        ),
    ),
    "CFUserNotificationPopUpSelection": (sel32or64(b"Ll", b"Qq"),),
    "CFStringConvertIANACharSetNameToEncoding": (
        sel32or64(b"L^{__CFString=}", b"I^{__CFString=}"),
    ),
    "CFDateFormatterGetTimeStyle": (
        sel32or64(b"l^{__CFDateFormatter=}", b"q^{__CFDateFormatter=}"),
    ),
    "CFSocketSetSocketFlags": (sel32or64(b"v^{__CFSocket=}L", b"v^{__CFSocket=}Q"),),
    "CFXMLCreateStringByUnescapingEntities": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringCreateWithSubstring": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^{__CFString=}{_CFRange=ll}",
            b"^{__CFString=}^{__CFAllocator=}^{__CFString=}{_CFRange=qq}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFWriteStreamSetDispatchQueue": (
        sel32or64(
            b"v^{__CFWriteStream=}^{dispatch_queue_s=}", b"v^{__CFWriteStream=}@"
        ),
    ),
    "CFStringCreateMutableCopy": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}l^{__CFString=}",
            b"^{__CFString=}^{__CFAllocator=}q^{__CFString=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleCopyExecutableArchitectures": (
        b"^{__CFArray=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDictionaryCreateCopy": (
        b"^{__CFDictionary=}^{__CFAllocator=}^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopPerformBlock": (
        b"v^{__CFRunLoop=}@@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"v"}},
                    },
                }
            }
        },
    ),
    "CFStringPad": (
        sel32or64(
            b"v^{__CFString=}^{__CFString=}ll", b"v^{__CFString=}^{__CFString=}qq"
        ),
    ),
    "CFLocaleGetValue": (b"@^{__CFLocale=}^{__CFString=}",),
    "CFLocaleCopyISOLanguageCodes": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFSocketSendData": (
        sel32or64(
            b"l^{__CFSocket=}^{__CFData=}^{__CFData=}d",
            b"q^{__CFSocket=}^{__CFData=}^{__CFData=}d",
        ),
    ),
    "CFDataIncreaseLength": (sel32or64(b"v^{__CFData=}l", b"v^{__CFData=}q"),),
    "CFBagGetValueIfPresent": (
        b"Z^{__CFBag=}@^@",
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CFBooleanGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFBundleCopyAuxiliaryExecutableURL": (
        b"^{__CFURL=}^{__CFBundle=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLEnumeratorCreateForMountedVolumes": (
        sel32or64(
            b"^{__CFURLEnumerator=}^{__CFAllocator=}L^{__CFArray=}",
            b"^{__CFURLEnumerator=}^{__CFAllocator=}Q^{__CFArray=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFFileSecurityGetMode": (
        b"Z^{__CFFileSecurity=}^S",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "CFReadStreamSetClient": (
        sel32or64(
            b"Z^{__CFReadStream=}L^?^{_CFStreamClientContext=l^v^?^?^?}",
            b"Z^{__CFReadStream=}Q^?^{_CFStreamClientContext=q^v^?^?^?}",
        ),
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFReadStream=}"},
                            1: {"type": b"Q"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "CFStringConvertEncodingToWindowsCodepage": (sel32or64(b"LL", b"II"),),
    "CFMachPortGetInvalidationCallBack": (b"^?^{__CFMachPort=}",),
    "CFURLCopyFileSystemPath": (
        sel32or64(b"^{__CFString=}^{__CFURL=}l", b"^{__CFString=}^{__CFURL=}q"),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopSourceSignal": (b"v^{__CFRunLoopSource=}",),
    "CFBundleCopyInfoDictionaryInDirectory": (
        b"^{__CFDictionary=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFUserNotificationDisplayAlert": (
        sel32or64(
            b"ldL^{__CFURL=}^{__CFURL=}^{__CFURL=}^{__CFString=}^{__CFString=}^{__CFString=}^{__CFString=}^{__CFString=}^L",
            b"idQ^{__CFURL=}^{__CFURL=}^{__CFURL=}^{__CFString=}^{__CFString=}^{__CFString=}^{__CFString=}^{__CFString=}^Q",
        ),
        "",
        {"arguments": {10: {"type_modifier": "o"}}},
    ),
    "CFURLClearResourcePropertyCacheForKey": (b"v^{__CFURL=}^{__CFString=}",),
    "CFBinaryHeapGetMinimum": (b"@^{__CFBinaryHeap=}",),
    "CFNotificationCenterAddObserver": (
        sel32or64(
            b"v^{__CFNotificationCenter=}@^?@@l", b"v^{__CFNotificationCenter=}@^?@@q"
        ),
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"@"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"@"},
                            4: {"type": b"@"},
                        },
                    }
                }
            }
        },
    ),
    "CFCalendarCopyTimeZone": (
        b"^{__CFTimeZone=}^{__CFCalendar=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAttributedStringGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFPropertyListWriteToStream": (
        sel32or64(
            b"l@^{__CFWriteStream=}l^^{__CFString=}",
            b"q@^{__CFWriteStream=}q^^{__CFString=}",
        ),
        "",
        {"arguments": {3: {"type_modifier": "o"}}},
    ),
    "CFBagAddValue": (b"v^{__CFBag=}@",),
    "CFCharacterSetCreateMutable": (
        b"^{__CFCharacterSet=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFTreeGetParent": (b"^{__CFTree=}^{__CFTree=}",),
    "CFCalendarGetComponentDifference": (
        sel32or64(b"Z^{__CFCalendar=}ddL^c", b"Z^{__CFCalendar=}ddQ^c"),
        "",
        {"variadic": True},
    ),
    "CFURLGetByteRangeForComponent": (
        sel32or64(
            b"{_CFRange=ll}^{__CFURL=}l^{_CFRange=ll}",
            b"{_CFRange=qq}^{__CFURL=}q^{_CFRange=qq}",
        ),
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CFRunLoopRunInMode": (sel32or64(b"l^{__CFString=}dZ", b"i^{__CFString=}dZ"),),
    "CFBundleCopyExecutableURL": (
        b"^{__CFURL=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringReplace": (
        sel32or64(
            b"v^{__CFString=}{_CFRange=ll}^{__CFString=}",
            b"v^{__CFString=}{_CFRange=qq}^{__CFString=}",
        ),
    ),
    "CFSocketGetNative": (b"i^{__CFSocket=}",),
    "CFConvertFloatSwappedToHost": (b"f{_CFSwappedFloat32=I}",),
    "CFBundleOpenBundleResourceMap": (
        sel32or64(b"s^{__CFBundle=}", b"i^{__CFBundle=}"),
    ),
    "CFDataFind": (
        sel32or64(
            b"{_CFRange=ll}^{__CFData=}^{__CFData=}{_CFRange=ll}L",
            b"{_CFRange=qq}^{__CFData=}^{__CFData=}{_CFRange=qq}Q",
        ),
    ),
    "CFMachPortCreate": (
        sel32or64(
            b"^{__CFMachPort=}^{__CFAllocator=}^?^{_CFMachPortContext=l^v^?^?^?}^Z",
            b"^{__CFMachPort=}^{__CFAllocator=}^?^{_CFMachPortContext=q^v^?^?^?}^Z",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFMachPort=}"},
                            1: {"type": b"^v"},
                            2: {"type": b"q"},
                            3: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFAttributedStringReplaceAttributedString": (
        sel32or64(
            b"v^{__CFAttributedString=}{_CFRange=ll}^{__CFAttributedString=}",
            b"v^{__CFAttributedString=}{_CFRange=qq}^{__CFAttributedString=}",
        ),
    ),
    "CFTimeZoneCreateWithName": (
        b"^{__CFTimeZone=}^{__CFAllocator=}^{__CFString=}Z",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleGetPackageInfoInDirectory": (
        sel32or64(b"Z^{__CFURL=}^L^L", b"Z^{__CFURL=}^I^I"),
        "",
        {"arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}}},
    ),
    "CFURLCreateData": (
        sel32or64(
            b"^{__CFData=}^{__CFAllocator=}^{__CFURL=}LZ",
            b"^{__CFData=}^{__CFAllocator=}^{__CFURL=}IZ",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFNumberFormatterCreateStringWithNumber": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFNumberFormatter=}^{__CFNumber=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCalendarGetMaximumRangeOfUnit": (
        sel32or64(b"{_CFRange=ll}^{__CFCalendar=}L", b"{_CFRange=qq}^{__CFCalendar=}Q"),
    ),
    "CFRunLoopRemoveSource": (b"v^{__CFRunLoop=}^{__CFRunLoopSource=}^{__CFString=}",),
    "CFSwapInt32": (b"II",),
    "CFXMLParserCreateWithDataFromURL": (
        sel32or64(
            b"^{__CFXMLParser=}^{__CFAllocator=}^{__CFURL=}Ll^{_CFXMLParserCallBacks=l^?^?^?^?^?}^{_CFXMLParserContext=l^v^?^?^?}",
            b"^{__CFXMLParser=}^{__CFAllocator=}^{__CFURL=}Qq^{_CFXMLParserCallBacks=q^?^?^?^?^?}^{_CFXMLParserContext=q^v^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopTimerGetNextFireDate": (b"d^{__CFRunLoopTimer=}",),
    "CFBitVectorGetCountOfBit": (
        sel32or64(
            b"l^{__CFBitVector=}{_CFRange=ll}L", b"q^{__CFBitVector=}{_CFRange=qq}I"
        ),
    ),
    "CFNotificationCenterGetDarwinNotifyCenter": (b"^{__CFNotificationCenter=}",),
    "CFPropertyListWrite": (
        sel32or64(
            b"l@^{__CFWriteStream=}lL^^{__CFError=}",
            b"q@^{__CFWriteStream=}qQ^^{__CFError=}",
        ),
        "",
        {
            "arguments": {
                4: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "CFDataAppendBytes": (
        sel32or64(b"v^{__CFData=}^vl", b"v^{__CFData=}^vq"),
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}}},
    ),
    "CFDictionaryGetCount": (
        sel32or64(b"l^{__CFDictionary=}", b"q^{__CFDictionary=}"),
    ),
    "CFLocaleCreateLocaleIdentifierFromWindowsLocaleCode": (
        b"^{__CFString=}^{__CFAllocator=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFUserNotificationUpdate": (
        sel32or64(
            b"l^{__CFUserNotification=}dL^{__CFDictionary=}",
            b"i^{__CFUserNotification=}dQ^{__CFDictionary=}",
        ),
    ),
    "CFMessagePortInvalidate": (b"v^{__CFMessagePort=}",),
    "CFSwapInt64": (b"QQ",),
    "CFURLCreateWithFileSystemPath": (
        sel32or64(
            b"^{__CFURL=}^{__CFAllocator=}^{__CFString=}lZ",
            b"^{__CFURL=}^{__CFAllocator=}^{__CFString=}qZ",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAttributedStringGetAttributes": (
        sel32or64(
            b"^{__CFDictionary=}^{__CFAttributedString=}l^{_CFRange=ll}",
            b"^{__CFDictionary=}^{__CFAttributedString=}q^{_CFRange=qq}",
        ),
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CFSocketSetDefaultNameRegistryPortNumber": (b"vS",),
    "CFFileSecurityGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFBundleCopyResourceURLsOfType": (
        b"^{__CFArray=}^{__CFBundle=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFConvertFloat32SwappedToHost": (b"f{_CFSwappedFloat32=I}",),
    "CFDictionaryReplaceValue": (b"v^{__CFDictionary=}@@",),
    "CFXMLTreeCreateFromDataWithError": (
        sel32or64(
            b"^{__CFTree=}^{__CFAllocator=}^{__CFData=}^{__CFURL=}Ll^^{__CFDictionary=}",
            b"^{__CFTree=}^{__CFAllocator=}^{__CFData=}^{__CFURL=}Qq^^{__CFDictionary=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {5: {"type_modifier": "o"}},
        },
    ),
    "CFTimeZoneSetDefault": (b"v^{__CFTimeZone=}",),
    "CFArrayApplyFunction": (
        sel32or64(b"v^{__CFArray=}{_CFRange=ll}^?@", b"v^{__CFArray=}{_CFRange=qq}^?@"),
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}, 1: {"type": b"@"}},
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFMessagePortGetInvalidationCallBack": (
        b"^?^{__CFMessagePort=}",
        "",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {0: {"type": b"@"}, 1: {"type": b"^v"}},
                }
            }
        },
    ),
    "CFUserNotificationGetResponseDictionary": (
        b"^{__CFDictionary=}^{__CFUserNotification=}",
    ),
    "CFSwapInt32HostToLittle": (b"II",),
    "CFSocketInvalidate": (b"v^{__CFSocket=}",),
    "CFStringGetMostCompatibleMacStringEncoding": (sel32or64(b"LL", b"II"),),
    "CFRunLoopObserverIsValid": (b"Z^{__CFRunLoopObserver=}",),
    "CFStringInsert": (
        sel32or64(b"v^{__CFString=}l^{__CFString=}", b"v^{__CFString=}q^{__CFString=}"),
    ),
    "CFXMLParserGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFMessagePortGetContext": (
        sel32or64(
            b"v^{__CFMessagePort=}^{_CFMessagePortContext=l^v^?^?^?}",
            b"v^{__CFMessagePort=}^{_CFMessagePortContext=q^v^?^?^?}",
        ),
    ),
    "CFStringIsEncodingAvailable": (sel32or64(b"ZL", b"ZI"),),
    "CFStringGetLength": (sel32or64(b"l^{__CFString=}", b"q^{__CFString=}"),),
    "CFURLCanBeDecomposed": (b"Z^{__CFURL=}",),
    "CFStringCreateWithCStringNoCopy": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^tL^{__CFAllocator=}",
            b"^{__CFString=}^{__CFAllocator=}^tI^{__CFAllocator=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "CFReadStreamClose": (b"v^{__CFReadStream=}",),
    "CFBagCreate": (
        sel32or64(
            b"^{__CFBag=}^{__CFAllocator=}^^vl^{_CFBagCallBacks=l^?^?^?^?^?}",
            b"^{__CFBag=}^{__CFAllocator=}^^vq^{_CFBagCallBacks=q^?^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopAddTimer": (b"v^{__CFRunLoop=}^{__CFRunLoopTimer=}^{__CFString=}",),
    "CFDictionaryGetValueIfPresent": (
        b"Z^{__CFDictionary=}@^@",
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CFArrayCreateCopy": (
        b"^{__CFArray=}^{__CFAllocator=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorGetLastIndexOfBit": (
        sel32or64(
            b"l^{__CFBitVector=}{_CFRange=ll}L", b"q^{__CFBitVector=}{_CFRange=qq}I"
        ),
    ),
    "CFDataCreateMutable": (
        sel32or64(b"^{__CFData=}^{__CFAllocator=}l", b"^{__CFData=}^{__CFAllocator=}q"),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringAppendCString": (
        sel32or64(b"v^{__CFString=}^tL", b"v^{__CFString=}^tI"),
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "CFLocaleGetIdentifier": (b"^{__CFString=}^{__CFLocale=}",),
    "CFStringConvertWindowsCodepageToEncoding": (sel32or64(b"LL", b"II"),),
    "CFTreeRemove": (b"v^{__CFTree=}",),
    "CFBundleCloseBundleResourceMap": (
        sel32or64(b"v^{__CFBundle=}s", b"v^{__CFBundle=}i"),
    ),
    "CFStreamCreateBoundPair": (
        sel32or64(
            b"v^{__CFAllocator=}^^{__CFReadStream=}^^{__CFWriteStream=}l",
            b"v^{__CFAllocator=}^^{__CFReadStream=}^^{__CFWriteStream=}q",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}},
        },
    ),
    "CFRunLoopTimerSetNextFireDate": (b"v^{__CFRunLoopTimer=}d",),
    "CFAllocatorSetDefault": (b"v^{__CFAllocator=}",),
    "CFPreferencesSetAppValue": (b"v^{__CFString=}@^{__CFString=}",),
    "CFTimeZoneGetNextDaylightSavingTimeTransition": (b"d^{__CFTimeZone=}d",),
    "CFDateFormatterGetFormat": (b"^{__CFString=}^{__CFDateFormatter=}",),
    "CFLocaleCreateLocaleIdentifierFromComponents": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFPreferencesSynchronize": (b"Z^{__CFString=}^{__CFString=}^{__CFString=}",),
    "CFReadStreamCopyDispatchQueue": (
        sel32or64(b"^{dispatch_queue_s=}^{__CFReadStream=}", b"@^{__CFReadStream=}"),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringGetMaximumSizeOfFileSystemRepresentation": (
        sel32or64(b"l^{__CFString=}", b"q^{__CFString=}"),
    ),
    "CFBundleCreate": (
        b"^{__CFBundle=}^{__CFAllocator=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLGetPortNumber": (sel32or64(b"l^{__CFURL=}", b"i^{__CFURL=}"),),
    "CFStringAppendCharacters": (
        sel32or64(b"v^{__CFString=}^Tl", b"v^{__CFString=}^Tq"),
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}}},
    ),
    "CFArrayGetLastIndexOfValue": (
        sel32or64(b"l^{__CFArray=}{_CFRange=ll}@", b"q^{__CFArray=}{_CFRange=qq}@"),
    ),
    "CFRunLoopTimerCreate": (
        sel32or64(
            b"^{__CFRunLoopTimer=}^{__CFAllocator=}ddLl^?^{_CFRunLoopTimerContext=l^v^?^?^?}",
            b"^{__CFRunLoopTimer=}^{__CFAllocator=}ddQq^?^{_CFRunLoopTimerContext=q^v^?^?^?}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFRunLoopTimer=}"},
                            1: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFLocaleCreate": (
        b"^{__CFLocale=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringHasSuffix": (b"Z^{__CFString=}^{__CFString=}",),
    "CFEqual": (b"Z@@",),
    "CFRunLoopGetNextTimerFireDate": (b"d^{__CFRunLoop=}^{__CFString=}",),
    "CFErrorCreate": (
        sel32or64(
            b"^{__CFError=}^{__CFAllocator=}^{__CFString=}l^{__CFDictionary=}",
            b"^{__CFError=}^{__CFAllocator=}^{__CFString=}q^{__CFDictionary=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringCreateByCombiningStrings": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFArray=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringCreateWithFileSystemRepresentation": (
        b"^{__CFString=}^{__CFAllocator=}^t",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "CFBundleGetPlugIn": (b"^{__CFBundle=}^{__CFBundle=}",),
    "CFAllocatorGetPreferredSizeForSize": (
        sel32or64(b"l^{__CFAllocator=}lL", b"q^{__CFAllocator=}qQ"),
    ),
    "CFDateFormatterSetFormat": (b"v^{__CFDateFormatter=}^{__CFString=}",),
    "CFBinaryHeapApplyFunction": (
        b"v^{__CFBinaryHeap=}^?@",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}, 1: {"type": b"@"}},
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFRunLoopTimerSetTolerance": (b"v^{__CFRunLoopTimer=}d",),
    "CFStringGetBytes": (
        sel32or64(
            b"l^{__CFString=}{_CFRange=ll}LCZ^tl^l",
            b"q^{__CFString=}{_CFRange=qq}ICZ^tq^q",
        ),
        "",
        {
            "arguments": {
                5: {"c_array_length_in_arg": (6, 7), "type_modifier": "o"},
                7: {"type_modifier": "o"},
            }
        },
    ),
    "CFLocaleCopyAvailableLocaleIdentifiers": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringCreateArrayBySeparatingStrings": (
        b"^{__CFArray=}^{__CFAllocator=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringGetDoubleValue": (b"d^{__CFString=}",),
    "CFStringCreateMutable": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}l", b"^{__CFString=}^{__CFAllocator=}q"
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFSetGetCount": (sel32or64(b"l^{__CFSet=}", b"q^{__CFSet=}"),),
    "CFURLCreateWithBytes": (
        sel32or64(
            b"^{__CFURL=}^{__CFAllocator=}^vlL^{__CFURL=}",
            b"^{__CFURL=}^{__CFAllocator=}^vqI^{__CFURL=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFStringCompareWithOptionsAndLocale": (
        sel32or64(
            b"l^{__CFString=}^{__CFString=}{_CFRange=ll}L^{__CFLocale=}",
            b"q^{__CFString=}^{__CFString=}{_CFRange=qq}Q^{__CFLocale=}",
        ),
    ),
    "CFPropertyListCreateFromStream": (
        sel32or64(
            b"@^{__CFAllocator=}^{__CFReadStream=}lL^l^^{__CFString=}",
            b"@^{__CFAllocator=}^{__CFReadStream=}qQ^q^^{__CFString=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {4: {"type_modifier": "o"}, 5: {"type_modifier": "o"}},
        },
    ),
    "CFAbsoluteTimeAddGregorianUnits": (
        sel32or64(
            b"dd^{__CFTimeZone=}{_CFGregorianUnits=llllld}",
            b"dd^{__CFTimeZone=}{_CFGregorianUnits=iiiiid}",
        ),
    ),
    "CFLocaleCopyCurrent": (
        b"^{__CFLocale=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDateFormatterGetLocale": (b"^{__CFLocale=}^{__CFDateFormatter=}",),
    "CFURLEnumeratorGetSourceDidChange": (b"Z^{__CFURLEnumerator=}",),
    "CFNullGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFStringUppercase": (b"v^{__CFString=}^{__CFLocale=}",),
    "CFTreeGetFirstChild": (b"^{__CFTree=}^{__CFTree=}",),
    "CFAbsoluteTimeGetDayOfYear": (
        sel32or64(b"ld^{__CFTimeZone=}", b"id^{__CFTimeZone=}"),
    ),
    "CFURLCreateFromFileSystemRepresentation": (
        sel32or64(
            b"^{__CFURL=}^{__CFAllocator=}^tlZ", b"^{__CFURL=}^{__CFAllocator=}^tqZ"
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "CFBundleGetInfoDictionary": (b"^{__CFDictionary=}^{__CFBundle=}",),
    "CFByteOrderGetCurrent": (sel32or64(b"l", b"q"),),
    "CFAttributedStringEndEditing": (b"v^{__CFAttributedString=}",),
    "CFUserNotificationCancel": (
        sel32or64(b"l^{__CFUserNotification=}", b"i^{__CFUserNotification=}"),
    ),
    "CFUserNotificationSecureTextField": (sel32or64(b"Ll", b"Qq"),),
    "CFBitVectorCreate": (
        sel32or64(
            b"^{__CFBitVector=}^{__CFAllocator=}^Cl",
            b"^{__CFBitVector=}^{__CFAllocator=}^Cq",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {"c_array_of_variable_length": True, "type_modifier": "n"}
            },
        },
    ),
    "CFCharacterSetRemoveCharactersInRange": (
        sel32or64(
            b"v^{__CFCharacterSet=}{_CFRange=ll}", b"v^{__CFCharacterSet=}{_CFRange=qq}"
        ),
    ),
    "CFMachPortSetInvalidationCallBack": (
        b"v^{__CFMachPort=}^?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFMachPort=}"},
                            1: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "CFCharacterSetAddCharactersInString": (b"v^{__CFCharacterSet=}^{__CFString=}",),
    "CFBitVectorGetBitAtIndex": (
        sel32or64(b"L^{__CFBitVector=}l", b"I^{__CFBitVector=}q"),
    ),
    "CFURLIsFileReferenceURL": (b"Z^{__CFURL=}",),
    "CFURLCopyPath": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFArrayGetFirstIndexOfValue": (
        sel32or64(b"l^{__CFArray=}{_CFRange=ll}@", b"q^{__CFArray=}{_CFRange=qq}@"),
    ),
    "CFCharacterSetCreateWithCharactersInRange": (
        sel32or64(
            b"^{__CFCharacterSet=}^{__CFAllocator=}{_CFRange=ll}",
            b"^{__CFCharacterSet=}^{__CFAllocator=}{_CFRange=qq}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCharacterSetIsLongCharacterMember": (
        sel32or64(b"Z^{__CFCharacterSet=}L", b"Z^{__CFCharacterSet=}I"),
    ),
    "CFUUIDCreateFromUUIDBytes": (
        b"^{__CFUUID=}^{__CFAllocator=}{_CFUUIDBytes=CCCCCCCCCCCCCCCC}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopAddSource": (b"v^{__CFRunLoop=}^{__CFRunLoopSource=}^{__CFString=}",),
    "CFDictionaryContainsValue": (b"Z^{__CFDictionary=}@",),
    "CFTimeZoneCopyKnownNames": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleCopyPreferredLocalizationsFromArray": (
        b"^{__CFArray=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorFlipBitAtIndex": (
        sel32or64(b"v^{__CFBitVector=}l", b"v^{__CFBitVector=}q"),
    ),
    "CFPropertyListCreateXMLData": (
        b"^{__CFData=}^{__CFAllocator=}@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCreateResourcePropertyForKeyFromBookmarkData": (
        b"@^{__CFAllocator=}^{__CFString=}^{__CFData=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDateGetAbsoluteTime": (b"d^{__CFDate=}",),
    "CFNumberIsFloatType": (b"Z^{__CFNumber=}",),
    "CFTreePrependChild": (b"v^{__CFTree=}^{__CFTree=}",),
    "CFRunLoopWakeUp": (b"v^{__CFRunLoop=}",),
    "CFDateFormatterCreateStringWithDate": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFDateFormatter=}^{__CFDate=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCharacterSetHasMemberInPlane": (
        sel32or64(b"Z^{__CFCharacterSet=}l", b"Z^{__CFCharacterSet=}q"),
    ),
    "CFURLCopyResourceSpecifier": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringFold": (
        sel32or64(b"v^{__CFString=}L^{__CFLocale=}", b"v^{__CFString=}Q^{__CFLocale=}"),
    ),
    "CFStringTokenizerCopyCurrentTokenAttribute": (
        sel32or64(b"@^{__CFStringTokenizer=}L", b"@^{__CFStringTokenizer=}Q"),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFNotificationCenterRemoveEveryObserver": (b"v^{__CFNotificationCenter=}@",),
    "CFMessagePortGetName": (b"^{__CFString=}^{__CFMessagePort=}",),
    "CFURLCopyPassword": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFWriteStreamClose": (b"v^{__CFWriteStream=}",),
    "CFMessagePortCreateRunLoopSource": (
        sel32or64(
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFMessagePort=}l",
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFMessagePort=}q",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringGetCString": (
        sel32or64(b"Z^{__CFString=}^tlL", b"Z^{__CFString=}^tqI"),
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "o"}}},
    ),
    "_CFAutoreleasePoolPrintPools": (b"v",),
    "CFPropertyListCreateData": (
        sel32or64(
            b"^{__CFData=}^{__CFAllocator=}@lL^^{__CFError=}",
            b"^{__CFData=}^{__CFAllocator=}@qQ^^{__CFError=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                4: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "CFURLCopyQueryString": (
        b"^{__CFString=}^{__CFURL=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopTimerCreateWithHandler": (
        sel32or64(
            b"^{__CFRunLoopTimer=}^{__CFAllocator=}ddLl@?",
            b"^{__CFRunLoopTimer=}^{__CFAllocator=}ddQq@?",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"^{__CFRunLoopTimer=}"},
                        },
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^{__CFRunLoopTimer=}"}},
                    },
                }
            },
        },
    ),
    "CFTimeZoneCopyAbbreviationDictionary": (
        b"^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringConvertEncodingToIANACharSetName": (
        sel32or64(b"^{__CFString=}L", b"^{__CFString=}I"),
    ),
    "CFSwapInt16LittleToHost": (b"SS",),
    "CFNumberFormatterSetProperty": (b"v^{__CFNumberFormatter=}^{__CFString=}@",),
    "CFSocketCopyPeerAddress": (
        b"^{__CFData=}^{__CFSocket=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCreateFromFileSystemRepresentationRelativeToBase": (
        sel32or64(
            b"^{__CFURL=}^{__CFAllocator=}^tlZ^{__CFURL=}",
            b"^{__CFURL=}^{__CFAllocator=}^tqZ^{__CFURL=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "CFAttributedStringSetAttributes": (
        sel32or64(
            b"v^{__CFAttributedString=}{_CFRange=ll}^{__CFDictionary=}Z",
            b"v^{__CFAttributedString=}{_CFRange=qq}^{__CFDictionary=}Z",
        ),
    ),
    "CFNumberFormatterCopyProperty": (
        b"@^{__CFNumberFormatter=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFSocketGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFURLGetBaseURL": (b"^{__CFURL=}^{__CFURL=}",),
    "CFSetGetCountOfValue": (sel32or64(b"l^{__CFSet=}@", b"q^{__CFSet=}@"),),
    "CFWriteStreamSetProperty": (b"Z^{__CFWriteStream=}^{__CFString=}@",),
    "CFDictionarySetValue": (b"v^{__CFDictionary=}@@",),
    "CFRunLoopSourceGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFWriteStreamCopyError": (
        b"^{__CFError=}^{__CFWriteStream=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorSetBits": (
        sel32or64(
            b"v^{__CFBitVector=}{_CFRange=ll}L", b"v^{__CFBitVector=}{_CFRange=qq}I"
        ),
    ),
    "CFURLCreateBookmarkDataFromAliasRecord": (
        b"^{__CFData=}^{__CFAllocator=}^{__CFData=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAttributedStringRemoveAttribute": (
        sel32or64(
            b"v^{__CFAttributedString=}{_CFRange=ll}^{__CFString=}",
            b"v^{__CFAttributedString=}{_CFRange=qq}^{__CFString=}",
        ),
    ),
    "CFURLCreateFromFSRef": (
        b"^{__CFURL=}^{__CFAllocator=}^{FSRef=[80C]}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "n"}},
        },
    ),
    "CFBitVectorFlipBits": (
        sel32or64(
            b"v^{__CFBitVector=}{_CFRange=ll}", b"v^{__CFBitVector=}{_CFRange=qq}"
        ),
    ),
    "CFCalendarCopyCurrent": (
        b"^{__CFCalendar=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopAddObserver": (b"v^{__CFRunLoop=}^{__CFRunLoopObserver=}^{__CFString=}",),
    "CFURLCreateCopyDeletingPathExtension": (
        b"^{__CFURL=}^{__CFAllocator=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFMessagePortIsValid": (b"Z^{__CFMessagePort=}",),
    "CFBundleCopySupportFilesDirectoryURL": (
        b"^{__CFURL=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFNumberGetType": (sel32or64(b"l^{__CFNumber=}", b"q^{__CFNumber=}"),),
    "CFDataCreateCopy": (
        b"^{__CFData=}^{__CFAllocator=}^{__CFData=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDictionaryCreateMutableCopy": (
        sel32or64(
            b"^{__CFDictionary=}^{__CFAllocator=}l^{__CFDictionary=}",
            b"^{__CFDictionary=}^{__CFAllocator=}q^{__CFDictionary=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringConvertEncodingToNSStringEncoding": (sel32or64(b"LL", b"QI"),),
    "CFXMLParserGetSourceURL": (b"^{__CFURL=}^{__CFXMLParser=}",),
    "CFSetContainsValue": (b"Z^{__CFSet=}@",),
    "CFBundleCopyInfoDictionaryForURL": (
        b"^{__CFDictionary=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFMessagePortSetInvalidationCallBack": (
        b"v^{__CFMessagePort=}^?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFMessagePort=}"},
                            1: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "CFTreeRemoveAllChildren": (b"v^{__CFTree=}",),
    "CFFileDescriptorIsValid": (b"Z^{__CFFileDescriptor=}",),
    "CFSetGetValueIfPresent": (
        b"Z^{__CFSet=}@^@",
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CFBinaryHeapGetCount": (
        sel32or64(b"l^{__CFBinaryHeap=}", b"q^{__CFBinaryHeap=}"),
    ),
    "CFRunLoopContainsObserver": (
        b"Z^{__CFRunLoop=}^{__CFRunLoopObserver=}^{__CFString=}",
    ),
    "CFRunLoopObserverGetOrder": (
        sel32or64(b"l^{__CFRunLoopObserver=}", b"q^{__CFRunLoopObserver=}"),
    ),
    "CFBagReplaceValue": (b"v^{__CFBag=}@",),
    "CFTreeSetContext": (
        sel32or64(
            b"v^{__CFTree=}^{_CFTreeContext=l^v^?^?^?}",
            b"v^{__CFTree=}^{_CFTreeContext=q^v^?^?^?}",
        ),
    ),
    "CFReadStreamCopyProperty": (
        b"@^{__CFReadStream=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringIsHyphenationAvailableForLocale": (b"Z^{__CFLocale=}",),
    "CFWriteStreamCopyDispatchQueue": (
        sel32or64(b"^{dispatch_queue_s=}^{__CFWriteStream=}", b"@^{__CFWriteStream=}"),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopSourceCreate": (
        sel32or64(
            b"^{__CFRunLoopSource=}^{__CFAllocator=}l^{_CFRunLoopSourceContext=l^v^?^?^?^?^?^?^?^?}",
            b"^{__CFRunLoopSource=}^{__CFAllocator=}q^{_CFRunLoopSourceContext=q^v^?^?^?^?^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCharacterSetInvert": (b"v^{__CFCharacterSet=}",),
    "CFMachPortInvalidate": (b"v^{__CFMachPort=}",),
    "CFSwapInt32BigToHost": (b"II",),
    "CFDataReplaceBytes": (
        sel32or64(b"v^{__CFData=}{_CFRange=ll}^vl", b"v^{__CFData=}{_CFRange=qq}^vq"),
        "",
        {"arguments": {2: {"c_array_length_in_arg": 3, "type_modifier": "n"}}},
    ),
    "CFDataGetBytePtr": (
        b"^v^{__CFData=}",
        "",
        {"retval": {"c_array_of_variable_length": True}},
    ),
    "CFSocketDisableCallBacks": (sel32or64(b"v^{__CFSocket=}L", b"v^{__CFSocket=}Q"),),
    "CFBundleCopyLocalizationsForURL": (
        b"^{__CFArray=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFReadStreamGetBuffer": (
        sel32or64(b"^v^{__CFReadStream=}l^l", b"^v^{__CFReadStream=}q^q"),
        "",
        {
            "retval": {"c_array_length_in_arg": 2},
            "arguments": {2: {"type_modifier": "o"}},
        },
    ),
    "CFErrorGetDomain": (b"^{__CFString=}^{__CFError=}",),
    "CFStringHasPrefix": (b"Z^{__CFString=}^{__CFString=}",),
    "CFTimeZoneIsDaylightSavingTime": (b"Z^{__CFTimeZone=}d",),
    "CFWriteStreamCanAcceptBytes": (b"Z^{__CFWriteStream=}",),
    "CFWriteStreamOpen": (b"Z^{__CFWriteStream=}",),
    "CFBitVectorSetCount": (sel32or64(b"v^{__CFBitVector=}l", b"v^{__CFBitVector=}q"),),
    "CFErrorCreateWithUserInfoKeysAndValues": (
        sel32or64(
            b"^{__CFError=}^{__CFAllocator=}^{__CFString=}l^@^@l",
            b"^{__CFError=}^{__CFAllocator=}^{__CFString=}q^@^@q",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                3: {"c_array_length_in_arg": 5, "type_modifier": "n"},
                4: {"c_array_length_in_arg": 5, "type_modifier": "n"},
            },
        },
    ),
    "CFUserNotificationCreate": (
        sel32or64(
            b"^{__CFUserNotification=}^{__CFAllocator=}dL^l^{__CFDictionary=}",
            b"^{__CFUserNotification=}^{__CFAllocator=}dQ^i^{__CFDictionary=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"type_modifier": "o"}},
        },
    ),
    "CFURLResourceIsReachable": (
        b"Z^{__CFURL=}^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "CFStringIsSurrogateHighCharacter": (b"ZT",),
    "CFPropertyListCreateWithData": (
        sel32or64(
            b"@^{__CFAllocator=}^{__CFData=}L^l^^{__CFError=}",
            b"@^{__CFAllocator=}^{__CFData=}Q^q^^{__CFError=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                3: {"type_modifier": "o"},
                4: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
            },
        },
    ),
    "CFSocketGetDefaultNameRegistryPortNumber": (b"S",),
    "CFBundleCopyLocalizationsForPreferences": (
        b"^{__CFArray=}^{__CFArray=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopObserverInvalidate": (b"v^{__CFRunLoopObserver=}",),
    "CFURLGetFSRef": (
        b"Z^{__CFURL=}^{FSRef=[80C]}",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "CFURLCreateCopyDeletingLastPathComponent": (
        b"^{__CFURL=}^{__CFAllocator=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleCreateBundlesFromDirectory": (
        b"^{__CFArray=}^{__CFAllocator=}^{__CFURL=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringFindCharacterFromSet": (
        sel32or64(
            b"Z^{__CFString=}^{__CFCharacterSet=}{_CFRange=ll}L^{_CFRange=ll}",
            b"Z^{__CFString=}^{__CFCharacterSet=}{_CFRange=qq}Q^{_CFRange=qq}",
        ),
        "",
        {"arguments": {4: {"type_modifier": "o"}}},
    ),
    "CFAttributedStringCreateMutable": (
        sel32or64(
            b"^{__CFAttributedString=}^{__CFAllocator=}l",
            b"^{__CFAttributedString=}^{__CFAllocator=}q",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFTreeGetContext": (
        sel32or64(
            b"v^{__CFTree=}^{_CFTreeContext=l^v^?^?^?}",
            b"v^{__CFTree=}^{_CFTreeContext=q^v^?^?^?}",
        ),
    ),
    "CFArrayCreateMutable": (
        sel32or64(
            b"^{__CFArray=}^{__CFAllocator=}l^{_CFArrayCallBacks=l^?^?^?^?}",
            b"^{__CFArray=}^{__CFAllocator=}q^{_CFArrayCallBacks=q^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFShow": (b"v@",),
    "CFFileSecuritySetOwner": (b"Z^{__CFFileSecurity=}I",),
    "CFSocketCopyAddress": (
        b"^{__CFData=}^{__CFSocket=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBagGetValues": (
        b"v^{__CFBag=}^@",
        "",
        {"arguments": {1: {"c_array_of_variable_length": True, "type_modifier": "o"}}},
    ),
    "CFFileSecuritySetOwnerUUID": (b"Z^{__CFFileSecurity=}^{__CFUUID=}",),
    "CFLocaleCreateCanonicalLocaleIdentifierFromScriptManagerCodes": (
        b"^{__CFString=}^{__CFAllocator=}ss",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDictionaryRemoveValue": (b"v^{__CFDictionary=}@",),
    "CFWriteStreamSetClient": (
        sel32or64(
            b"Z^{__CFWriteStream=}L^?^{_CFStreamClientContext=l^v^?^?^?}",
            b"Z^{__CFWriteStream=}Q^?^{_CFStreamClientContext=q^v^?^?^?}",
        ),
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFWriteStream=}"},
                            1: {"type": b"Q"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "CFRunLoopSourceIsValid": (b"Z^{__CFRunLoopSource=}",),
    "CFCharacterSetIsCharacterMember": (b"Z^{__CFCharacterSet=}T",),
    "CFTreeGetChildCount": (sel32or64(b"l^{__CFTree=}", b"q^{__CFTree=}"),),
    "CFURLSetTemporaryResourcePropertyForKey": (b"v^{__CFURL=}^{__CFString=}@",),
    "CFConvertDoubleHostToSwapped": (b"{_CFSwappedFloat64=Q}d",),
    "CFSetGetValue": (b"@^{__CFSet=}@",),
    "CFMessagePortSendRequest": (
        sel32or64(
            b"l^{__CFMessagePort=}l^{__CFData=}dd^{__CFString=}^^{__CFData=}",
            b"i^{__CFMessagePort=}i^{__CFData=}dd^{__CFString=}^^{__CFData=}",
        ),
        "",
        {"arguments": {6: {"type_modifier": "o"}}},
    ),
    "CFUUIDGetConstantUUIDWithBytes": (
        b"^{__CFUUID=}^{__CFAllocator=}CCCCCCCCCCCCCCCC",
    ),
    "CFSocketCreateRunLoopSource": (
        sel32or64(
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFSocket=}l",
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFSocket=}q",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFWriteStreamCreateWithBuffer": (
        sel32or64(
            b"^{__CFWriteStream=}^{__CFAllocator=}^vl",
            b"^{__CFWriteStream=}^{__CFAllocator=}^vq",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFXMLTreeCreateXMLData": (
        b"^{__CFData=}^{__CFAllocator=}^{__CFTree=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCopyUserName": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCopyAbsoluteURL": (
        b"^{__CFURL=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFNumberGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFStringCompareWithOptions": (
        sel32or64(
            b"l^{__CFString=}^{__CFString=}{_CFRange=ll}L",
            b"q^{__CFString=}^{__CFString=}{_CFRange=qq}Q",
        ),
    ),
    "CFWriteStreamGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFSwapInt16": (b"SS",),
    "CFDateGetTimeIntervalSinceDate": (b"d^{__CFDate=}^{__CFDate=}",),
    "CFAttributedStringGetString": (b"^{__CFString=}^{__CFAttributedString=}",),
    "CFURLCopyNetLocation": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringFind": (
        sel32or64(
            b"{_CFRange=ll}^{__CFString=}^{__CFString=}L",
            b"{_CFRange=qq}^{__CFString=}^{__CFString=}Q",
        ),
    ),
    "CFConvertFloat64HostToSwapped": (b"{_CFSwappedFloat64=Q}d",),
    "CFSetReplaceValue": (b"v^{__CFSet=}@",),
    "CFURLCreateCopyAppendingPathExtension": (
        b"^{__CFURL=}^{__CFAllocator=}^{__CFURL=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFTimeZoneCreate": (
        b"^{__CFTimeZone=}^{__CFAllocator=}^{__CFString=}^{__CFData=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCopyScheme": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFXMLParserParse": (b"Z^{__CFXMLParser=}",),
    "CFRunLoopRemoveTimer": (b"v^{__CFRunLoop=}^{__CFRunLoopTimer=}^{__CFString=}",),
    "CFPreferencesAppValueIsForced": (b"Z^{__CFString=}^{__CFString=}",),
    "CFSocketCreate": (
        sel32or64(
            b"^{__CFSocket=}^{__CFAllocator=}lllL^?^{_CFSocketContext=l^v^?^?^?}",
            b"^{__CFSocket=}^{__CFAllocator=}iiiQ^?^{_CFSocketContext=q^v^?^?^?}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFSocket=}"},
                            1: {"type": b"Q"},
                            2: {"type": b"^{__CFData=}"},
                            3: {"type": b"^v"},
                            4: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFNotificationCenterGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFURLCreateStringByReplacingPercentEscapes": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorContainsBit": (
        sel32or64(
            b"Z^{__CFBitVector=}{_CFRange=ll}L", b"Z^{__CFBitVector=}{_CFRange=qq}I"
        ),
    ),
    "CFMachPortCreateWithPort": (
        sel32or64(
            b"^{__CFMachPort=}^{__CFAllocator=}I^?^{_CFMachPortContext=l^v^?^?^?}^Z",
            b"^{__CFMachPort=}^{__CFAllocator=}I^?^{_CFMachPortContext=q^v^?^?^?}^Z",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFMachPort=}"},
                            1: {"type": b"^v"},
                            2: {"type": b"q"},
                            3: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFPreferencesAppSynchronize": (b"Z^{__CFString=}",),
    "CFFileDescriptorGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFBundleCopyBundleLocalizations": (
        b"^{__CFArray=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFFileSecurityCreate": (
        b"^{__CFFileSecurity=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFHash": (sel32or64(b"L@", b"Q@"),),
    "CFCharacterSetIntersect": (b"v^{__CFCharacterSet=}^{__CFCharacterSet=}",),
    "CFXMLNodeCreateCopy": (
        b"^{__CFXMLNode=}^{__CFAllocator=}^{__CFXMLNode=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFArrayCreate": (
        sel32or64(
            b"^{__CFArray=}^{__CFAllocator=}^^vl^{_CFArrayCallBacks=l^?^?^?^?}",
            b"^{__CFArray=}^{__CFAllocator=}^^vq^{_CFArrayCallBacks=q^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBooleanGetValue": (b"Z^{__CFBoolean=}",),
    "CFArrayContainsValue": (
        sel32or64(b"Z^{__CFArray=}{_CFRange=ll}@", b"Z^{__CFArray=}{_CFRange=qq}@"),
    ),
    "CFSwapInt32HostToBig": (b"II",),
    "CFURLWriteDataAndPropertiesToResource": (
        sel32or64(
            b"Z^{__CFURL=}^{__CFData=}^{__CFDictionary=}^l",
            b"Z^{__CFURL=}^{__CFData=}^{__CFDictionary=}^i",
        ),
        "",
        {"arguments": {3: {"type_modifier": "o"}}},
    ),
    "CFArrayInsertValueAtIndex": (sel32or64(b"v^{__CFArray=}l@", b"v^{__CFArray=}q@"),),
    "CFDictionaryCreateMutable": (
        sel32or64(
            b"^{__CFDictionary=}^{__CFAllocator=}l^{_CFDictionaryKeyCallBacks=l^?^?^?^?^?}^{_CFDictionaryValueCallBacks=l^?^?^?^?}",
            b"^{__CFDictionary=}^{__CFAllocator=}q^{_CFDictionaryKeyCallBacks=q^?^?^?^?^?}^{_CFDictionaryValueCallBacks=q^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAllocatorGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFReadStreamRead": (
        sel32or64(b"l^{__CFReadStream=}^vl", b"q^{__CFReadStream=}^vq"),
        "",
        {
            "arguments": {
                1: {
                    "c_array_length_in_result": True,
                    "type_modifier": "o",
                    "c_array_length_in_arg": 2,
                }
            }
        },
    ),
    "CFDataGetBytes": (
        sel32or64(b"v^{__CFData=}{_CFRange=ll}^v", b"v^{__CFData=}{_CFRange=qq}^v"),
        "",
        {"arguments": {2: {"c_array_length_in_arg": 1, "type_modifier": "o"}}},
    ),
    "CFStringCreateWithCharactersNoCopy": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^Tl^{__CFAllocator=}",
            b"^{__CFString=}^{__CFAllocator=}^Tq^{__CFAllocator=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "CFStringGetLongCharacterForSurrogatePair": (sel32or64(b"LTT", b"ITT"),),
    "CFSetAddValue": (b"v^{__CFSet=}@",),
    "CFFileSecuritySetMode": (b"Z^{__CFFileSecurity=}S",),
    "CFURLCreateStringByAddingPercentEscapes": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFString=}^{__CFString=}L",
            b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFString=}^{__CFString=}I",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringGetIntValue": (sel32or64(b"l^{__CFString=}", b"i^{__CFString=}"),),
    "CFDictionaryGetCountOfValue": (
        sel32or64(b"l^{__CFDictionary=}@", b"q^{__CFDictionary=}@"),
    ),
    "CFDataGetMutableBytePtr": (
        b"^v^{__CFData=}",
        "",
        {"retval": {"c_array_of_variable_length": True}},
    ),
    "CFURLCreateAbsoluteURLWithBytes": (
        sel32or64(
            b"^{__CFURL=}^{__CFAllocator=}^vlL^{__CFURL=}Z",
            b"^{__CFURL=}^{__CFAllocator=}^vqI^{__CFURL=}Z",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFBundleOpenBundleResourceFiles": (
        sel32or64(b"l^{__CFBundle=}^s^s", b"i^{__CFBundle=}^i^i"),
        "",
        {"arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}}},
    ),
    "CFRunLoopTimerGetInterval": (b"d^{__CFRunLoopTimer=}",),
    "CFFileSecurityGetOwner": (
        b"Z^{__CFFileSecurity=}^I",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "CFCalendarGetIdentifier": (b"^{__CFString=}^{__CFCalendar=}",),
    "CFStringCompare": (
        sel32or64(b"l^{__CFString=}^{__CFString=}L", b"q^{__CFString=}^{__CFString=}Q"),
    ),
    "CFURLClearResourcePropertyCache": (b"v^{__CFURL=}",),
    "CFRunLoopSourceInvalidate": (b"v^{__CFRunLoopSource=}",),
    "CFCalendarCreateWithIdentifier": (
        b"^{__CFCalendar=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFMachPortGetPort": (b"I^{__CFMachPort=}",),
    "CFBinaryHeapRemoveMinimumValue": (b"v^{__CFBinaryHeap=}",),
    "CFBagRemoveValue": (b"v^{__CFBag=}@",),
    "CFStringReplaceAll": (b"v^{__CFString=}^{__CFString=}",),
    "CFArraySetValueAtIndex": (sel32or64(b"v^{__CFArray=}l@", b"v^{__CFArray=}q@"),),
    "CFBundleCopyExecutableArchitecturesForURL": (
        b"^{__CFArray=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopObserverDoesRepeat": (b"Z^{__CFRunLoopObserver=}",),
    "CFDateCompare": (
        sel32or64(b"l^{__CFDate=}^{__CFDate=}^v", b"q^{__CFDate=}^{__CFDate=}^v"),
    ),
    "CFGregorianDateIsValid": (
        sel32or64(b"Z{_CFGregorianDate=lccccd}L", b"Z{_CFGregorianDate=iccccd}Q"),
    ),
    "CFAutorelease": (b"@@",),
    "CFRunLoopTimerInvalidate": (b"v^{__CFRunLoopTimer=}",),
    "CFDictionaryGetCountOfKey": (
        sel32or64(b"l^{__CFDictionary=}@", b"q^{__CFDictionary=}@"),
    ),
    "CFStringGetCharacterAtIndex": (
        sel32or64(b"T^{__CFString=}l", b"T^{__CFString=}q"),
    ),
    "CFStringCreateWithCString": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^tL", b"^{__CFString=}^{__CFAllocator=}^tI"
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "CFReadStreamCopyError": (
        b"^{__CFError=}^{__CFReadStream=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFUserNotificationCheckBoxChecked": (sel32or64(b"Ll", b"Qq"),),
    "CFAttributedStringCreate": (
        b"^{__CFAttributedString=}^{__CFAllocator=}^{__CFString=}^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringFindWithOptions": (
        sel32or64(
            b"Z^{__CFString=}^{__CFString=}{_CFRange=ll}L^{_CFRange=ll}",
            b"Z^{__CFString=}^{__CFString=}{_CFRange=qq}Q^{_CFRange=qq}",
        ),
        "",
        {"arguments": {4: {"type_modifier": "o"}}},
    ),
    "CFSetRemoveAllValues": (b"v^{__CFSet=}",),
    "CFArraySortValues": (
        sel32or64(b"v^{__CFArray=}{_CFRange=ll}^?@", b"v^{__CFArray=}{_CFRange=qq}^?@"),
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"l"},
                        "arguments": {
                            0: {"type": b"@"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFCalendarGetFirstWeekday": (
        sel32or64(b"l^{__CFCalendar=}", b"q^{__CFCalendar=}"),
    ),
    "CFStreamCreatePairWithPeerSocketSignature": (
        sel32or64(
            b"v^{__CFAllocator=}^{_CFSocketSignature=lll^{__CFData=}}^^{__CFReadStream=}^^{__CFWriteStream=}",
            b"v^{__CFAllocator=}^{_CFSocketSignature=iii^{__CFData=}}^^{__CFReadStream=}^^{__CFWriteStream=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {"type_modifier": "n"},
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
            },
        },
    ),
    "CFURLSetResourcePropertiesForKeys": (
        b"Z^{__CFURL=}^{__CFDictionary=}^^{__CFError=}",
        "",
        {
            "arguments": {
                2: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "CFXMLParserGetLocation": (
        sel32or64(b"l^{__CFXMLParser=}", b"q^{__CFXMLParser=}"),
    ),
    "CFStringTokenizerGetCurrentTokenRange": (
        sel32or64(
            b"{_CFRange=ll}^{__CFStringTokenizer=}",
            b"{_CFRange=qq}^{__CFStringTokenizer=}",
        ),
    ),
    "CFBagContainsValue": (b"Z^{__CFBag=}@",),
    "CFUUIDCreateWithBytes": (
        b"^{__CFUUID=}^{__CFAllocator=}CCCCCCCCCCCCCCCC",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFArrayGetCount": (sel32or64(b"l^{__CFArray=}", b"q^{__CFArray=}"),),
    "CFArrayCreateMutableCopy": (
        sel32or64(
            b"^{__CFArray=}^{__CFAllocator=}l^{__CFArray=}",
            b"^{__CFArray=}^{__CFAllocator=}q^{__CFArray=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFSetSetValue": (b"v^{__CFSet=}@",),
    "CFSwapInt64HostToBig": (b"QQ",),
    "CFCharacterSetUnion": (b"v^{__CFCharacterSet=}^{__CFCharacterSet=}",),
    "CFFileSecurityCopyGroupUUID": (
        b"Z^{__CFFileSecurity=}^^{__CFUUID=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "o"}},
        },
    ),
    "CFAttributedStringSetAttribute": (
        sel32or64(
            b"v^{__CFAttributedString=}{_CFRange=ll}^{__CFString=}@",
            b"v^{__CFAttributedString=}{_CFRange=qq}^{__CFString=}@",
        ),
    ),
    "CFReadStreamOpen": (b"Z^{__CFReadStream=}",),
    "CFXMLNodeGetVersion": (sel32or64(b"l^{__CFXMLNode=}", b"q^{__CFXMLNode=}"),),
    "CFStringCreateWithBytesNoCopy": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^tlLZ^{__CFAllocator=}",
            b"^{__CFString=}^{__CFAllocator=}^tqIZ^{__CFAllocator=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFBundleGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFURLDestroyResource": (
        sel32or64(b"Z^{__CFURL=}^l", b"Z^{__CFURL=}^i"),
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "CFBagSetValue": (b"v^{__CFBag=}@",),
    "CFURLWriteBookmarkDataToFile": (
        sel32or64(
            b"Z^{__CFData=}^{__CFURL=}L^^{__CFError=}",
            b"Z^{__CFData=}^{__CFURL=}Q^^{__CFError=}",
        ),
        "",
        {
            "arguments": {
                3: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "CFFileDescriptorCreateRunLoopSource": (
        sel32or64(
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFFileDescriptor=}l",
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFFileDescriptor=}q",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFGetTypeID": (sel32or64(b"L@", b"Q@"),),
    "CFURLCopyFragment": (
        b"^{__CFString=}^{__CFURL=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFWriteStreamCreateWithFile": (
        b"^{__CFWriteStream=}^{__CFAllocator=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAbsoluteTimeGetDifferenceAsGregorianUnits": (
        sel32or64(
            b"{_CFGregorianUnits=llllld}dd^{__CFTimeZone=}L",
            b"{_CFGregorianUnits=iiiiid}dd^{__CFTimeZone=}Q",
        ),
    ),
    "CFReadStreamCreateWithFile": (
        b"^{__CFReadStream=}^{__CFAllocator=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleCopyLocalizedString": (
        b"^{__CFString=}^{__CFBundle=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFErrorCopyRecoverySuggestion": (
        b"^{__CFString=}^{__CFError=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCreateBookmarkData": (
        sel32or64(
            b"^{__CFData=}^{__CFAllocator=}^{__CFURL=}L^{__CFArray=}^{__CFURL=}^^{__CFError=}",
            b"^{__CFData=}^{__CFAllocator=}^{__CFURL=}Q^{__CFArray=}^{__CFURL=}^^{__CFError=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                5: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "CFStringCreateWithBytes": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^tlLZ",
            b"^{__CFString=}^{__CFAllocator=}^tqIZ",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFRunLoopSourceGetOrder": (
        sel32or64(b"l^{__CFRunLoopSource=}", b"q^{__CFRunLoopSource=}"),
    ),
    "CFBundleLoadExecutable": (b"Z^{__CFBundle=}",),
    "CFStringCreateCopy": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCreateFilePathURL": (
        b"^{__CFURL=}^{__CFAllocator=}^{__CFURL=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "CFUserNotificationDisplayNotice": (
        sel32or64(
            b"ldL^{__CFURL=}^{__CFURL=}^{__CFURL=}^{__CFString=}^{__CFString=}^{__CFString=}",
            b"idQ^{__CFURL=}^{__CFURL=}^{__CFURL=}^{__CFString=}^{__CFString=}^{__CFString=}",
        ),
    ),
    "CFUserNotificationGetResponseValue": (
        sel32or64(
            b"^{__CFString=}^{__CFUserNotification=}^{__CFString=}l",
            b"^{__CFString=}^{__CFUserNotification=}^{__CFString=}q",
        ),
    ),
    "CFRunLoopContainsTimer": (b"Z^{__CFRunLoop=}^{__CFRunLoopTimer=}^{__CFString=}",),
    "CFPreferencesSetValue": (
        b"v^{__CFString=}@^{__CFString=}^{__CFString=}^{__CFString=}",
    ),
    "CFReadStreamGetStatus": (
        sel32or64(b"l^{__CFReadStream=}", b"q^{__CFReadStream=}"),
    ),
    "CFCopyTypeIDDescription": (
        sel32or64(b"^{__CFString=}L", b"^{__CFString=}Q"),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFConvertFloatHostToSwapped": (b"{_CFSwappedFloat32=I}f",),
    "CFCalendarDecomposeAbsoluteTime": (
        b"Z^{__CFCalendar=}d^c",
        "",
        {"variadic": True},
    ),
    "CFBinaryHeapCreate": (
        sel32or64(
            b"^{__CFBinaryHeap=}^{__CFAllocator=}l^{_CFBinaryHeapCallBacks=l^?^?^?^?}^{_CFBinaryHeapCompareContext=l^v^?^?^?}",
            b"^{__CFBinaryHeap=}^{__CFAllocator=}q^{_CFBinaryHeapCallBacks=q^?^?^?^?}^{_CFBinaryHeapCompareContext=q^v^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringCreateExternalRepresentation": (
        sel32or64(
            b"^{__CFData=}^{__CFAllocator=}^{__CFString=}LC",
            b"^{__CFData=}^{__CFAllocator=}^{__CFString=}IC",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDateFormatterCreateISO8601Formatter": (
        b"^{__CFDateFormatter=}^{__CFAllocator=}Q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringCreateWithFormat": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFDictionary=}^{__CFString=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"printf_format": True}},
            "variadic": True,
        },
    ),
    "CFBundleCopyResourceURLsOfTypeForLocalization": (
        b"^{__CFArray=}^{__CFBundle=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFConvertFloat32HostToSwapped": (b"{_CFSwappedFloat32=I}f",),
    "CFRunLoopObserverCreateWithHandler": (
        sel32or64(
            b"^{__CFRunLoopObserver=}^{__CFAllocator=}LZl@?",
            b"^{__CFRunLoopObserver=}^{__CFAllocator=}QZq@?",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"^{__CFRunLoopObserver=}"},
                            2: {"type": sel32or64(b"I", b"Q")},
                        },
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFRunLoopObserver=}"},
                            1: {"type": b"L"},
                        },
                    },
                }
            },
        },
    ),
    "CFDataCreate": (
        sel32or64(
            b"^{__CFData=}^{__CFAllocator=}^vl", b"^{__CFData=}^{__CFAllocator=}^vq"
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFSwapInt16HostToLittle": (b"SS",),
    "CFSetCreate": (
        sel32or64(
            b"^{__CFSet=}^{__CFAllocator=}^^vl^{_CFSetCallBacks=l^?^?^?^?^?}",
            b"^{__CFSet=}^{__CFAllocator=}^^vq^{_CFSetCallBacks=q^?^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFGregorianDateGetAbsoluteTime": (
        sel32or64(
            b"d{_CFGregorianDate=lccccd}^{__CFTimeZone=}",
            b"d{_CFGregorianDate=iccccd}^{__CFTimeZone=}",
        ),
    ),
    "CFStringGetListOfAvailableEncodings": (
        sel32or64(b"^L", b"^I"),
        "",
        {"retval": {"c_array_of_variable_length": True}},
    ),
    "CFRunLoopTimerGetContext": (
        sel32or64(
            b"v^{__CFRunLoopTimer=}^{_CFRunLoopTimerContext=l^v^?^?^?}",
            b"v^{__CFRunLoopTimer=}^{_CFRunLoopTimerContext=q^v^?^?^?}",
        ),
    ),
    "CFXMLParserAbort": (
        sel32or64(
            b"v^{__CFXMLParser=}l^{__CFString=}", b"v^{__CFXMLParser=}q^{__CFString=}"
        ),
    ),
    "CFPropertyListCreateFromXMLData": (
        sel32or64(
            b"@^{__CFAllocator=}^{__CFData=}L^^{__CFString=}",
            b"@^{__CFAllocator=}^{__CFData=}Q^^{__CFString=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"type_modifier": "o"}},
        },
    ),
    "CFStringFindAndReplace": (
        sel32or64(
            b"l^{__CFString=}^{__CFString=}^{__CFString=}{_CFRange=ll}L",
            b"q^{__CFString=}^{__CFString=}^{__CFString=}{_CFRange=qq}Q",
        ),
    ),
    "CFDictionaryGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFBundleGetDevelopmentRegion": (b"^{__CFString=}^{__CFBundle=}",),
    "CFBundleGetMainBundle": (b"^{__CFBundle=}",),
    "CFXMLNodeCreate": (
        sel32or64(
            b"^{__CFXMLNode=}^{__CFAllocator=}l^{__CFString=}^vl",
            b"^{__CFXMLNode=}^{__CFAllocator=}q^{__CFString=}^vq",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleUnloadExecutable": (b"v^{__CFBundle=}",),
    "CFArrayGetCountOfValue": (
        sel32or64(b"l^{__CFArray=}{_CFRange=ll}@", b"q^{__CFArray=}{_CFRange=qq}@"),
    ),
    "CFRunLoopTimerIsValid": (b"Z^{__CFRunLoopTimer=}",),
    "CFConvertFloat64SwappedToHost": (b"d{_CFSwappedFloat64=Q}",),
    "CFReadStreamHasBytesAvailable": (b"Z^{__CFReadStream=}",),
    "CFDataSetLength": (sel32or64(b"v^{__CFData=}l", b"v^{__CFData=}q"),),
    "CFStringTokenizerCreate": (
        sel32or64(
            b"^{__CFStringTokenizer=}^{__CFAllocator=}^{__CFString=}{_CFRange=ll}L^{__CFLocale=}",
            b"^{__CFStringTokenizer=}^{__CFAllocator=}^{__CFString=}{_CFRange=qq}Q^{__CFLocale=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFMachPortGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFTreeGetChildAtIndex": (
        sel32or64(b"^{__CFTree=}^{__CFTree=}l", b"^{__CFTree=}^{__CFTree=}q"),
    ),
    "CFSwapInt16BigToHost": (b"SS",),
    "CFStringCreateWithCharacters": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^Tl", b"^{__CFString=}^{__CFAllocator=}^Tq"
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "CFUserNotificationCreateRunLoopSource": (
        sel32or64(
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFUserNotification=}^?l",
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFUserNotification=}^?q",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFUserNotification=}"},
                            1: {"type": sel32or64(b"i", b"q")},
                        },
                    },
                    "function_pointer_retained": True,
                }
            },
        },
    ),
    "CFStringTrimWhitespace": (b"v^{__CFString=}",),
    "CFMessagePortCreateRemote": (
        b"^{__CFMessagePort=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringDelete": (
        sel32or64(b"v^{__CFString=}{_CFRange=ll}", b"v^{__CFString=}{_CFRange=qq}"),
    ),
    "CFBundleCopyResourceURLInDirectory": (
        b"^{__CFURL=}^{__CFURL=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFTreeFindRoot": (b"^{__CFTree=}^{__CFTree=}",),
    "CFLocaleCopyDisplayNameForPropertyValue": (
        b"^{__CFString=}^{__CFLocale=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringTokenizerGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFSocketGetSocketFlags": (sel32or64(b"L^{__CFSocket=}", b"Q^{__CFSocket=}"),),
    "CFLocaleGetLanguageLineDirection": (
        sel32or64(b"l^{__CFString=}", b"q^{__CFString=}"),
    ),
    "CFCopyHomeDirectoryURL": (
        b"^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFUUIDCreateFromString": (
        b"^{__CFUUID=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFPreferencesCopyApplicationList": (
        b"^{__CFArray=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFErrorCopyUserInfo": (
        b"^{__CFDictionary=}^{__CFError=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFMachPortIsValid": (b"Z^{__CFMachPort=}",),
    "CFCalendarComposeAbsoluteTime": (b"Z^{__CFCalendar=}^d^c", "", {"variadic": True}),
    "CFReadStreamUnscheduleFromRunLoop": (
        b"v^{__CFReadStream=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "CFDictionaryGetValue": (b"@^{__CFDictionary=}@",),
    "CFReadStreamCreateWithBytesNoCopy": (
        sel32or64(
            b"^{__CFReadStream=}^{__CFAllocator=}^vl^{__CFAllocator=}",
            b"^{__CFReadStream=}^{__CFAllocator=}^vq^{__CFAllocator=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFSwapInt32LittleToHost": (b"II",),
    "CFBinaryHeapRemoveAllValues": (b"v^{__CFBinaryHeap=}",),
    "CFWriteStreamGetStatus": (
        sel32or64(b"l^{__CFWriteStream=}", b"q^{__CFWriteStream=}"),
    ),
    "CFURLCreateFileReferenceURL": (
        b"^{__CFURL=}^{__CFAllocator=}^{__CFURL=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "CFRunLoopObserverGetActivities": (
        sel32or64(b"L^{__CFRunLoopObserver=}", b"Q^{__CFRunLoopObserver=}"),
    ),
    "CFTimeZoneCreateWithTimeIntervalFromGMT": (
        b"^{__CFTimeZone=}^{__CFAllocator=}d",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFPropertyListCreateWithStream": (
        sel32or64(
            b"@^{__CFAllocator=}^{__CFReadStream=}lL^l^^{__CFError=}",
            b"@^{__CFAllocator=}^{__CFReadStream=}qQ^q^^{__CFError=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                4: {"type_modifier": "o"},
                5: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
            },
        },
    ),
    "CFFileSecurityClearProperties": (
        sel32or64(b"Z^{__CFFileSecurity=}L", b"Z^{__CFFileSecurity=}Q"),
    ),
    "CFURLCopyResourcePropertyForKey": (
        b"Z^{__CFURL=}^{__CFString=}^@^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {"already_cfretained": True, "type_modifier": "o"},
                3: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
            },
        },
    ),
    "CFDateFormatterCopyProperty": (
        b"@^{__CFDateFormatter=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFSwapInt64LittleToHost": (b"QQ",),
    "CFUserNotificationReceiveResponse": (
        sel32or64(b"l^{__CFUserNotification=}d^L", b"i^{__CFUserNotification=}d^Q"),
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CFNumberFormatterGetLocale": (b"^{__CFLocale=}^{__CFNumberFormatter=}",),
    "CFURLStartAccessingSecurityScopedResource": (b"Z^{__CFURL=}",),
    "CFMachPortCreateRunLoopSource": (
        sel32or64(
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFMachPort=}l",
            b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__CFMachPort=}q",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLGetBytes": (
        sel32or64(b"l^{__CFURL=}^Cl", b"q^{__CFURL=}^Cq"),
        "",
        {
            "arguments": {
                1: {
                    "c_array_length_in_arg": 2,
                    "c_array_length_in_result": True,
                    "type_modifier": "o",
                }
            }
        },
    ),
    "CFFileDescriptorGetNativeDescriptor": (b"i^{__CFFileDescriptor=}",),
    "CFTimeZoneSetAbbreviationDictionary": (b"v^{__CFDictionary=}",),
    "CFUserNotificationGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFTimeZoneCopySystem": (
        b"^{__CFTimeZone=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFShowStr": (b"v^{__CFString=}",),
    "CFURLEnumeratorGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFBundleCopyResourceURL": (
        b"^{__CFURL=}^{__CFBundle=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorGetBits": (
        sel32or64(
            b"v^{__CFBitVector=}{_CFRange=ll}^C", b"v^{__CFBitVector=}{_CFRange=qq}^C"
        ),
        "",
        {"arguments": {2: {"c_array_of_variable_length": True, "type_modifier": "o"}}},
    ),
    "CFFileSecuritySetGroup": (b"Z^{__CFFileSecurity=}I",),
    "CFNotificationCenterGetLocalCenter": (b"^{__CFNotificationCenter=}",),
    "CFTimeZoneGetData": (b"^{__CFData=}^{__CFTimeZone=}",),
    "CFArrayReplaceValues": (
        sel32or64(b"v^{__CFArray=}{_CFRange=ll}^@l", b"v^{__CFArray=}{_CFRange=qq}^@q"),
        "",
        {"arguments": {2: {"c_array_length_in_arg": 3, "type_modifier": "n"}}},
    ),
    "CFStringGetCharactersPtr": (
        b"^T^{__CFString=}",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "CFStringTokenizerGoToTokenAtIndex": (
        sel32or64(b"L^{__CFStringTokenizer=}l", b"Q^{__CFStringTokenizer=}q"),
    ),
    "CFBundleGetIdentifier": (b"^{__CFString=}^{__CFBundle=}",),
    "CFTreeApplyFunctionToChildren": (
        b"v^{__CFTree=}^?@",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}, 1: {"type": b"@"}},
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFDataGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFRunLoopAddCommonMode": (b"v^{__CFRunLoop=}^{__CFString=}",),
    "CFCalendarSetLocale": (b"v^{__CFCalendar=}^{__CFLocale=}",),
    "CFStreamCreatePairWithSocketToHost": (
        sel32or64(
            b"v^{__CFAllocator=}^{__CFString=}L^^{__CFReadStream=}^^{__CFWriteStream=}",
            b"v^{__CFAllocator=}^{__CFString=}I^^{__CFReadStream=}^^{__CFWriteStream=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"type_modifier": "o"}, 4: {"type_modifier": "o"}},
        },
    ),
    "CFNumberCreate": (
        sel32or64(
            b"^{__CFNumber=}^{__CFAllocator=}l^v", b"^{__CFNumber=}^{__CFAllocator=}q^v"
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCharacterSetAddCharactersInRange": (
        sel32or64(
            b"v^{__CFCharacterSet=}{_CFRange=ll}", b"v^{__CFCharacterSet=}{_CFRange=qq}"
        ),
    ),
    "CFMessagePortIsRemote": (b"Z^{__CFMessagePort=}",),
    "CFURLGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFReadStreamGetError": (
        sel32or64(
            b"{_CFStreamError=ll}^{__CFReadStream=}",
            b"{_CFStreamError=qi}^{__CFReadStream=}",
        ),
    ),
    "CFBagCreateMutableCopy": (
        sel32or64(
            b"^{__CFBag=}^{__CFAllocator=}l^{__CFBag=}",
            b"^{__CFBag=}^{__CFAllocator=}q^{__CFBag=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFWriteStreamCreateWithAllocatedBuffers": (
        b"^{__CFWriteStream=}^{__CFAllocator=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBagGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFCalendarGetTimeRangeOfUnit": (
        sel32or64(b"Z^{__CFCalendar=}Ld^d^d", b"Z^{__CFCalendar=}Qd^d^d"),
        "",
        {"arguments": {3: {"type_modifier": "o"}, 4: {"type_modifier": "o"}}},
    ),
    "CFBundlePreflightExecutable": (
        b"Z^{__CFBundle=}^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "CFArrayRemoveAllValues": (b"v^{__CFArray=}",),
    "CFStringGetLineBounds": (
        sel32or64(
            b"v^{__CFString=}{_CFRange=ll}^l^l^l", b"v^{__CFString=}{_CFRange=qq}^q^q^q"
        ),
        "",
        {
            "arguments": {
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
                4: {"type_modifier": "o"},
            }
        },
    ),
    "CFTimeZoneCopyAbbreviation": (
        b"^{__CFString=}^{__CFTimeZone=}d",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFFileSecurityGetGroup": (
        b"Z^{__CFFileSecurity=}^I",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "CFCharacterSetGetPredefined": (
        sel32or64(b"^{__CFCharacterSet=}l", b"^{__CFCharacterSet=}q"),
    ),
    "CFArrayRemoveValueAtIndex": (sel32or64(b"v^{__CFArray=}l", b"v^{__CFArray=}q"),),
    "CFStringGetSmallestEncoding": (sel32or64(b"L^{__CFString=}", b"I^{__CFString=}"),),
    "CFTreeAppendChild": (b"v^{__CFTree=}^{__CFTree=}",),
    "CFURLCreatePropertyFromResource": (
        sel32or64(
            b"@^{__CFAllocator=}^{__CFURL=}^{__CFString=}^l",
            b"@^{__CFAllocator=}^{__CFURL=}^{__CFString=}^i",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"type_modifier": "o"}},
        },
    ),
    "CFURLCopyHostName": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAbsoluteTimeGetDayOfWeek": (
        sel32or64(b"ld^{__CFTimeZone=}", b"id^{__CFTimeZone=}"),
    ),
    "CFSwapInt64HostToLittle": (b"QQ",),
    "CFArrayExchangeValuesAtIndices": (
        sel32or64(b"v^{__CFArray=}ll", b"v^{__CFArray=}qq"),
    ),
    "CFTimeZoneGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFRunLoopObserverCreate": (
        sel32or64(
            b"^{__CFRunLoopObserver=}^{__CFAllocator=}LZl^?^{_CFRunLoopObserverContext=l^v^?^?^?}",
            b"^{__CFRunLoopObserver=}^{__CFAllocator=}QZq^?^{_CFRunLoopObserverContext=q^v^?^?^?}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFRunLoopObserver=}"},
                            1: {"type": b"Q"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFRunLoopTimerGetTolerance": (b"d^{__CFRunLoopTimer=}",),
    "CFBinaryHeapCreateCopy": (
        sel32or64(
            b"^{__CFBinaryHeap=}^{__CFAllocator=}l^{__CFBinaryHeap=}",
            b"^{__CFBinaryHeap=}^{__CFAllocator=}q^{__CFBinaryHeap=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringCreateFromExternalRepresentation": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^{__CFData=}L",
            b"^{__CFString=}^{__CFAllocator=}^{__CFData=}I",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFTimeZoneResetSystem": (b"v",),
    "CFStringNormalize": (sel32or64(b"v^{__CFString=}l", b"v^{__CFString=}q"),),
    "CFRunLoopContainsSource": (
        b"Z^{__CFRunLoop=}^{__CFRunLoopSource=}^{__CFString=}",
    ),
    "CFLocaleCreateCanonicalLanguageIdentifierFromString": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFDictionaryApplyFunction": (
        b"v^{__CFDictionary=}^?@",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"@"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFLocaleGetLanguageCharacterDirection": (
        sel32or64(b"l^{__CFString=}", b"q^{__CFString=}"),
    ),
    "CFStringCreateArrayWithFindResults": (
        sel32or64(
            b"^{__CFArray=}^{__CFAllocator=}^{__CFString=}^{__CFString=}{_CFRange=ll}L",
            b"^{__CFArray=}^{__CFAllocator=}^{__CFString=}^{__CFString=}{_CFRange=qq}Q",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFArrayGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFNumberFormatterSetFormat": (b"v^{__CFNumberFormatter=}^{__CFString=}",),
    "CFStreamCreatePairWithSocket": (
        b"v^{__CFAllocator=}i^^{__CFReadStream=}^^{__CFWriteStream=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"type_modifier": "o"}, 3: {"type_modifier": "o"}},
        },
    ),
    "CFBitVectorCreateMutableCopy": (
        sel32or64(
            b"^{__CFBitVector=}^{__CFAllocator=}l^{__CFBitVector=}",
            b"^{__CFBitVector=}^{__CFAllocator=}q^{__CFBitVector=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFPreferencesGetAppBooleanValue": (
        b"Z^{__CFString=}^{__CFString=}^Z",
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CFSocketSetAddress": (
        sel32or64(b"l^{__CFSocket=}^{__CFData=}", b"q^{__CFSocket=}^{__CFData=}"),
    ),
    "CFRunLoopCopyAllModes": (
        b"^{__CFArray=}^{__CFRunLoop=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCreateStringByReplacingPercentEscapesUsingEncoding": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFString=}L",
            b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFString=}I",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopRun": (b"v",),
    "CFPreferencesGetAppIntegerValue": (
        sel32or64(
            b"l^{__CFString=}^{__CFString=}^Z", b"q^{__CFString=}^{__CFString=}^Z"
        ),
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "CFMessagePortSetName": (b"Z^{__CFMessagePort=}^{__CFString=}",),
    "CFDateFormatterCreate": (
        sel32or64(
            b"^{__CFDateFormatter=}^{__CFAllocator=}^{__CFLocale=}ll",
            b"^{__CFDateFormatter=}^{__CFAllocator=}^{__CFLocale=}qq",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFUUIDCreateString": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFUUID=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFNumberFormatterCreate": (
        sel32or64(
            b"^{__CFNumberFormatter=}^{__CFAllocator=}^{__CFLocale=}l",
            b"^{__CFNumberFormatter=}^{__CFAllocator=}^{__CFLocale=}q",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFXMLParserGetStatusCode": (
        sel32or64(b"l^{__CFXMLParser=}", b"q^{__CFXMLParser=}"),
    ),
    "CFCalendarGetMinimumRangeOfUnit": (
        sel32or64(b"{_CFRange=ll}^{__CFCalendar=}L", b"{_CFRange=qq}^{__CFCalendar=}Q"),
    ),
    "CFBitVectorCreateCopy": (
        b"^{__CFBitVector=}^{__CFAllocator=}^{__CFBitVector=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFTimeZoneGetSecondsFromGMT": (b"d^{__CFTimeZone=}d",),
    "CFRunLoopTimerDoesRepeat": (b"Z^{__CFRunLoopTimer=}",),
    "CFCharacterSetCreateInvertedSet": (
        b"^{__CFCharacterSet=}^{__CFAllocator=}^{__CFCharacterSet=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringGetParagraphBounds": (
        sel32or64(
            b"v^{__CFString=}{_CFRange=ll}^l^l^l", b"v^{__CFString=}{_CFRange=qq}^q^q^q"
        ),
        "",
        {
            "arguments": {
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
                4: {"type_modifier": "o"},
            }
        },
    ),
    "CFStringGetSystemEncoding": (sel32or64(b"L", b"I"),),
    "CFBundleCopyResourceURLsOfTypeInDirectory": (
        b"^{__CFArray=}^{__CFURL=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAttributedStringCreateMutableCopy": (
        sel32or64(
            b"^{__CFAttributedString=}^{__CFAllocator=}l^{__CFAttributedString=}",
            b"^{__CFAttributedString=}^{__CFAllocator=}q^{__CFAttributedString=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringTokenizerGetCurrentSubTokens": (
        sel32or64(
            b"l^{__CFStringTokenizer=}^{_CFRange=ll}l^{__CFArray=}",
            b"q^{__CFStringTokenizer=}^{_CFRange=qq}q^{__CFArray=}",
        ),
        "",
        {
            "arguments": {
                1: {
                    "c_array_length_in_result": True,
                    "c_array_length_in_arg": 2,
                    "type_modifier": "o",
                }
            }
        },
    ),
    "CFBundleCopyBundleURL": (
        b"^{__CFURL=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFXMLNodeGetInfoPtr": (b"^v^{__CFXMLNode=}",),
    "CFSocketCreateConnectedToSocketSignature": (
        sel32or64(
            b"^{__CFSocket=}^{__CFAllocator=}^{_CFSocketSignature=lll^{__CFData=}}L^?^{_CFSocketContext=l^v^?^?^?}d",
            b"^{__CFSocket=}^{__CFAllocator=}^{_CFSocketSignature=iii^{__CFData=}}Q^?^{_CFSocketContext=q^v^?^?^?}d",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFSocket=}"},
                            1: {"type": b"Q"},
                            2: {"type": b"^{__CFData=}"},
                            3: {"type": b"^v"},
                            4: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFURLCreateDataAndPropertiesFromResource": (
        sel32or64(
            b"Z^{__CFAllocator=}^{__CFURL=}^^{__CFData=}^^{__CFDictionary=}^{__CFArray=}^l",
            b"Z^{__CFAllocator=}^{__CFURL=}^^{__CFData=}^^{__CFDictionary=}^{__CFArray=}^i",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
                5: {"type_modifier": "o"},
            },
        },
    ),
    "CFAbsoluteTimeGetWeekOfYear": (
        sel32or64(b"ld^{__CFTimeZone=}", b"id^{__CFTimeZone=}"),
    ),
    "CFDateFormatterSetProperty": (b"v^{__CFDateFormatter=}^{__CFString=}@",),
    "CFTreeGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFRunLoopStop": (b"v^{__CFRunLoop=}",),
    "CFNotificationCenterPostNotification": (
        b"v^{__CFNotificationCenter=}^{__CFString=}@^{__CFDictionary=}Z",
    ),
    "CFXMLTreeCreateFromData": (
        sel32or64(
            b"^{__CFTree=}^{__CFAllocator=}^{__CFData=}^{__CFURL=}Ll",
            b"^{__CFTree=}^{__CFAllocator=}^{__CFData=}^{__CFURL=}Qq",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleCopyBuiltInPlugInsURL": (
        b"^{__CFURL=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFXMLTreeCreateWithDataFromURL": (
        sel32or64(
            b"^{__CFTree=}^{__CFAllocator=}^{__CFURL=}Ll",
            b"^{__CFTree=}^{__CFAllocator=}^{__CFURL=}Qq",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFLocaleCreateComponentsFromLocaleIdentifier": (
        b"^{__CFDictionary=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFPropertyListIsValid": (sel32or64(b"Z@l", b"Z@q"),),
    "CFNumberFormatterGetDecimalInfoForCurrencyCode": (
        b"Z^{__CFString=}^i^d",
        "",
        {"arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}}},
    ),
    "CFSocketEnableCallBacks": (sel32or64(b"v^{__CFSocket=}L", b"v^{__CFSocket=}Q"),),
    "CFSetCreateCopy": (
        b"^{__CFSet=}^{__CFAllocator=}^{__CFSet=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFSwapInt64BigToHost": (b"QQ",),
    "CFReadStreamGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFFileDescriptorCreate": (
        sel32or64(
            b"^{__CFFileDescriptor=}^{__CFAllocator=}iZ^?^{_CFFileDescriptorContext=l^v^?^?^?}",
            b"^{__CFFileDescriptor=}^{__CFAllocator=}iZ^?^{_CFFileDescriptorContext=q^v^?^?^?}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFFileDescriptor=}"},
                            1: {"type": b"Q"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFBagCreateMutable": (
        sel32or64(
            b"^{__CFBag=}^{__CFAllocator=}l^{_CFBagCallBacks=l^?^?^?^?^?}",
            b"^{__CFBag=}^{__CFAllocator=}q^{_CFBagCallBacks=q^?^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLCreateWithString": (
        b"^{__CFURL=}^{__CFAllocator=}^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDictionaryAddValue": (b"v^{__CFDictionary=}@@",),
    "CFFileSecurityCreateCopy": (
        b"^{__CFFileSecurity=}^{__CFAllocator=}^{__CFFileSecurity=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCharacterSetRemoveCharactersInString": (b"v^{__CFCharacterSet=}^{__CFString=}",),
    "CFRunLoopRemoveObserver": (
        b"v^{__CFRunLoop=}^{__CFRunLoopObserver=}^{__CFString=}",
    ),
    "CFAttributedStringGetMutableString": (b"^{__CFString=}^{__CFAttributedString=}",),
    "CFDictionaryCreate": (
        sel32or64(
            b"^{__CFDictionary=}^{__CFAllocator=}^^v^^vl^{_CFDictionaryKeyCallBacks=l^?^?^?^?^?}^{_CFDictionaryValueCallBacks=l^?^?^?^?}",
            b"^{__CFDictionary=}^{__CFAllocator=}^^v^^vq^{_CFDictionaryKeyCallBacks=q^?^?^?^?^?}^{_CFDictionaryValueCallBacks=q^?^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFNumberGetByteSize": (sel32or64(b"l^{__CFNumber=}", b"q^{__CFNumber=}"),),
    "CFXMLParserCopyErrorDescription": (
        b"^{__CFString=}^{__CFXMLParser=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCharacterSetCreateWithBitmapRepresentation": (
        b"^{__CFCharacterSet=}^{__CFAllocator=}^{__CFData=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleGetValueForInfoDictionaryKey": (b"@^{__CFBundle=}^{__CFString=}",),
    "CFXMLParserGetCallBacks": (
        sel32or64(
            b"v^{__CFXMLParser=}^{_CFXMLParserCallBacks=l^?^?^?^?^?}",
            b"v^{__CFXMLParser=}^{_CFXMLParserCallBacks=q^?^?^?^?^?}",
        ),
    ),
    "CFWriteStreamUnscheduleFromRunLoop": (
        b"v^{__CFWriteStream=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "CFAttributedStringCreateCopy": (
        b"^{__CFAttributedString=}^{__CFAllocator=}^{__CFAttributedString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorSetBitAtIndex": (
        sel32or64(b"v^{__CFBitVector=}lL", b"v^{__CFBitVector=}qI"),
    ),
    "CFReadStreamSetDispatchQueue": (
        sel32or64(b"v^{__CFReadStream=}^{dispatch_queue_s=}", b"v^{__CFReadStream=}@"),
    ),
    "CFMessagePortSetDispatchQueue": (
        sel32or64(
            b"v^{__CFMessagePort=}^{dispatch_queue_s=}", b"v^{__CFMessagePort=}@"
        ),
    ),
    "CFStringGetNameOfEncoding": (sel32or64(b"^{__CFString=}L", b"^{__CFString=}I"),),
    "CFBitVectorSetAllBits": (
        sel32or64(b"v^{__CFBitVector=}L", b"v^{__CFBitVector=}I"),
    ),
    "CFSocketGetContext": (
        sel32or64(
            b"v^{__CFSocket=}^{_CFSocketContext=l^v^?^?^?}",
            b"v^{__CFSocket=}^{_CFSocketContext=q^v^?^?^?}",
        ),
    ),
    "CFLocaleGetWindowsLocaleCodeFromLocaleIdentifier": (b"I^{__CFString=}",),
    "CFXMLParserGetLineNumber": (
        sel32or64(b"l^{__CFXMLParser=}", b"q^{__CFXMLParser=}"),
    ),
    "CFTimeZoneGetDaylightSavingTimeOffset": (b"d^{__CFTimeZone=}d",),
    "CFPreferencesAddSuitePreferencesToApp": (b"v^{__CFString=}^{__CFString=}",),
    "CFURLGetFileSystemRepresentation": (
        sel32or64(b"Z^{__CFURL=}Z^tl", b"Z^{__CFURL=}Z^tq"),
        "",
        {
            "arguments": {
                2: {
                    "c_array_delimited_by_null": True,
                    "type_modifier": "o",
                    "c_array_length_in_arg": 3,
                }
            }
        },
    ),
    "CFSetApplyFunction": (
        b"v^{__CFSet=}^?@",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}, 1: {"type": b"@"}},
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFStringCapitalize": (b"v^{__CFString=}^{__CFLocale=}",),
    "CFBinaryHeapGetMinimumIfPresent": (
        b"Z^{__CFBinaryHeap=}^@",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "CFURLCopyPathExtension": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFLocaleCopyISOCountryCodes": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFLocaleCreateCopy": (
        b"^{__CFLocale=}^{__CFAllocator=}^{__CFLocale=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFURLEnumeratorSkipDescendents": (b"v^{__CFURLEnumerator=}",),
    "CFBinaryHeapAddValue": (b"v^{__CFBinaryHeap=}@",),
    "CFBinaryHeapGetValues": (b"v^{__CFBinaryHeap=}^^v",),
    "CFDateFormatterGetAbsoluteTimeFromString": (
        sel32or64(
            b"Z^{__CFDateFormatter=}^{__CFString=}^{_CFRange=ll}^d",
            b"Z^{__CFDateFormatter=}^{__CFString=}^{_CFRange=qq}^d",
        ),
        "",
        {"arguments": {2: {"type_modifier": "N"}, 3: {"type_modifier": "o"}}},
    ),
    "CFTreeSortChildren": (
        b"v^{__CFTree=}^?@",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"l"},
                        "arguments": {
                            0: {"type": b"@"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFURLCopyResourcePropertiesForKeys": (
        b"^{__CFDictionary=}^{__CFURL=}^{__CFArray=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "CFNumberCompare": (
        sel32or64(
            b"l^{__CFNumber=}^{__CFNumber=}^v", b"q^{__CFNumber=}^{__CFNumber=}^v"
        ),
    ),
    "CFURLHasDirectoryPath": (b"Z^{__CFURL=}",),
    "CFSwapInt16HostToBig": (b"SS",),
    "CFXMLCreateStringByEscapingEntities": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFPreferencesSetMultiple": (
        b"v^{__CFDictionary=}^{__CFArray=}^{__CFString=}^{__CFString=}^{__CFString=}",
    ),
    "CFBagGetValue": (b"@^{__CFBag=}@",),
    "CFBundleGetBundleWithIdentifier": (b"^{__CFBundle=}^{__CFString=}",),
    "CFMakeCollectable": (b"@@",),
    "CFSetGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFStringAppendFormat": (
        b"v^{__CFString=}^{__CFDictionary=}^{__CFString=}",
        "",
        {"arguments": {2: {"printf_format": True}}, "variadic": True},
    ),
    "CFNumberGetValue": (sel32or64(b"Z^{__CFNumber=}l^v", b"Z^{__CFNumber=}q^v"),),
    "CFStringTokenizerSetString": (
        sel32or64(
            b"v^{__CFStringTokenizer=}^{__CFString=}{_CFRange=ll}",
            b"v^{__CFStringTokenizer=}^{__CFString=}{_CFRange=qq}",
        ),
    ),
    "CFRunLoopGetMain": (b"^{__CFRunLoop=}",),
    "CFDictionaryRemoveAllValues": (b"v^{__CFDictionary=}",),
    "CFPropertyListCreateDeepCopy": (
        sel32or64(b"@^{__CFAllocator=}@L", b"@^{__CFAllocator=}@Q"),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFUUIDGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFNotificationCenterPostNotificationWithOptions": (
        sel32or64(
            b"v^{__CFNotificationCenter=}^{__CFString=}@^{__CFDictionary=}L",
            b"v^{__CFNotificationCenter=}^{__CFString=}@^{__CFDictionary=}Q",
        ),
    ),
    "CFStringLowercase": (b"v^{__CFString=}^{__CFLocale=}",),
    "CFCalendarSetMinimumDaysInFirstWeek": (
        sel32or64(b"v^{__CFCalendar=}l", b"v^{__CFCalendar=}q"),
    ),
    "CFRetain": (b"@@",),
    "CFStringGetCharacters": (
        sel32or64(b"v^{__CFString=}{_CFRange=ll}^T", b"v^{__CFString=}{_CFRange=qq}^T"),
        "",
        {"arguments": {2: {"c_array_length_in_arg": 1, "type_modifier": "o"}}},
    ),
    "CFTimeZoneGetName": (b"^{__CFString=}^{__CFTimeZone=}",),
    "CFURLCopyStrictPath": (
        b"^{__CFString=}^{__CFURL=}^Z",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "o"}},
        },
    ),
    "CFBundleIsExecutableLoaded": (b"Z^{__CFBundle=}",),
    "CFArrayAppendArray": (
        sel32or64(
            b"v^{__CFArray=}^{__CFArray=}{_CFRange=ll}",
            b"v^{__CFArray=}^{__CFArray=}{_CFRange=qq}",
        ),
    ),
    "CFNumberFormatterGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFDateGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFPreferencesCopyMultiple": (
        b"^{__CFDictionary=}^{__CFArray=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFBinaryHeapGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFTimeZoneCopyLocalizedName": (
        sel32or64(
            b"^{__CFString=}^{__CFTimeZone=}l^{__CFLocale=}",
            b"^{__CFString=}^{__CFTimeZone=}q^{__CFLocale=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCalendarCopyLocale": (
        b"^{__CFLocale=}^{__CFCalendar=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFFileDescriptorDisableCallBacks": (
        sel32or64(b"v^{__CFFileDescriptor=}L", b"v^{__CFFileDescriptor=}Q"),
    ),
    "CFBundleLoadExecutableAndReturnError": (
        b"Z^{__CFBundle=}^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "CFNumberFormatterCreateNumberFromString": (
        sel32or64(
            b"^{__CFNumber=}^{__CFAllocator=}^{__CFNumberFormatter=}^{__CFString=}^{_CFRange=ll}L",
            b"^{__CFNumber=}^{__CFAllocator=}^{__CFNumberFormatter=}^{__CFString=}^{_CFRange=qq}Q",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"type_modifier": "N"}},
        },
    ),
    "CFAttributedStringGetAttribute": (
        sel32or64(
            b"@^{__CFAttributedString=}l^{__CFString=}^{_CFRange=ll}",
            b"@^{__CFAttributedString=}q^{__CFString=}^{_CFRange=qq}",
        ),
        "",
        {"arguments": {3: {"type_modifier": "o"}}},
    ),
    "CFURLCopyLastPathComponent": (
        b"^{__CFString=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleCopyResourcesDirectoryURL": (
        b"^{__CFURL=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopGetCurrent": (b"^{__CFRunLoop=}",),
    "CFDateFormatterCreateDateFromString": (
        sel32or64(
            b"^{__CFDate=}^{__CFAllocator=}^{__CFDateFormatter=}^{__CFString=}^{_CFRange=ll}",
            b"^{__CFDate=}^{__CFAllocator=}^{__CFDateFormatter=}^{__CFString=}^{_CFRange=qq}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"type_modifier": "N"}},
        },
    ),
    "CFURLEnumeratorGetDescendentLevel": (
        sel32or64(b"l^{__CFURLEnumerator=}", b"q^{__CFURLEnumerator=}"),
    ),
    "CFStringGetSurrogatePairForLongCharacter": (
        sel32or64(b"ZL^T", b"ZI^T"),
        "",
        {"arguments": {1: {"c_array_of_fixed_length": 2, "type_modifier": "o"}}},
    ),
    "CFBagApplyFunction": (
        b"v^{__CFBag=}^?@",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}, 1: {"type": b"@"}},
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFBundleCopySharedSupportURL": (
        b"^{__CFURL=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFCharacterSetCreateWithCharactersInString": (
        b"^{__CFCharacterSet=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFPreferencesCopyKeyList": (
        b"^{__CFArray=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDateFormatterGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFRunLoopSourceGetContext": (
        sel32or64(
            b"v^{__CFRunLoopSource=}^{_CFRunLoopSourceContext=l^v^?^?^?^?^?^?^?^?}",
            b"v^{__CFRunLoopSource=}^{_CFRunLoopSourceContext=q^v^?^?^?^?^?^?^?^?}",
        ),
    ),
    "CFBundleGetAllBundles": (b"^{__CFArray=}",),
    "CFFileSecuritySetGroupUUID": (b"Z^{__CFFileSecurity=}^{__CFUUID=}",),
    "CFCharacterSetCreateMutableCopy": (
        b"^{__CFCharacterSet=}^{__CFAllocator=}^{__CFCharacterSet=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringGetRangeOfComposedCharactersAtIndex": (
        sel32or64(b"{_CFRange=ll}^{__CFString=}l", b"{_CFRange=qq}^{__CFString=}q"),
    ),
    "CFAttributedStringBeginEditing": (b"v^{__CFAttributedString=}",),
    "CFNumberFormatterGetFormat": (b"^{__CFString=}^{__CFNumberFormatter=}",),
    "CFErrorGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFURLCopyParameterString": (
        b"^{__CFString=}^{__CFURL=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFAttributedStringGetAttributesAndLongestEffectiveRange": (
        sel32or64(
            b"^{__CFDictionary=}^{__CFAttributedString=}l{_CFRange=ll}^{_CFRange=ll}",
            b"^{__CFDictionary=}^{__CFAttributedString=}q{_CFRange=qq}^{_CFRange=qq}",
        ),
        "",
        {"arguments": {3: {"type_modifier": "o"}}},
    ),
    "CFXMLParserGetContext": (
        sel32or64(
            b"v^{__CFXMLParser=}^{_CFXMLParserContext=l^v^?^?^?}",
            b"v^{__CFXMLParser=}^{_CFXMLParserContext=q^v^?^?^?}",
        ),
    ),
    "CFCopyDescription": (
        b"^{__CFString=}@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFDataDeleteBytes": (
        sel32or64(b"v^{__CFData=}{_CFRange=ll}", b"v^{__CFData=}{_CFRange=qq}"),
    ),
    "CFWriteStreamGetError": (
        sel32or64(
            b"{_CFStreamError=ll}^{__CFWriteStream=}",
            b"{_CFStreamError=qi}^{__CFWriteStream=}",
        ),
    ),
    "CFURLCreateResourcePropertiesForKeysFromBookmarkData": (
        b"^{__CFDictionary=}^{__CFAllocator=}^{__CFArray=}^{__CFData=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBitVectorGetFirstIndexOfBit": (
        sel32or64(
            b"l^{__CFBitVector=}{_CFRange=ll}L", b"q^{__CFBitVector=}{_CFRange=qq}I"
        ),
    ),
    "CFCharacterSetCreateCopy": (
        b"^{__CFCharacterSet=}^{__CFAllocator=}^{__CFCharacterSet=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFStringCreateMutableWithExternalCharactersNoCopy": (
        sel32or64(
            b"^{__CFString=}^{__CFAllocator=}^Tll^{__CFAllocator=}",
            b"^{__CFString=}^{__CFAllocator=}^Tqq^{__CFAllocator=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "CFRunLoopCopyCurrentMode": (
        b"^{__CFString=}^{__CFRunLoop=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFBundleGetPackageInfo": (
        sel32or64(b"v^{__CFBundle=}^L^L", b"v^{__CFBundle=}^I^I"),
        "",
        {"arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}}},
    ),
    "CFCalendarSetFirstWeekday": (
        sel32or64(b"v^{__CFCalendar=}l", b"v^{__CFCalendar=}q"),
    ),
    "CFStringGetFastestEncoding": (sel32or64(b"L^{__CFString=}", b"I^{__CFString=}"),),
    "CFSocketIsValid": (b"Z^{__CFSocket=}",),
    "CFTreeGetChildren": (
        b"v^{__CFTree=}^^{__CFTree=}",
        "",
        {"arguments": {1: {"c_array_of_variable_length": True, "type_modifier": "o"}}},
    ),
    "CFBundleGetLocalInfoDictionary": (b"^{__CFDictionary=}^{__CFBundle=}",),
    "CFArrayBSearchValues": (
        sel32or64(
            b"l^{__CFArray=}{_CFRange=ll}@^?@", b"q^{__CFArray=}{_CFRange=qq}@^?@"
        ),
        "",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"l"},
                        "arguments": {
                            0: {"type": b"@"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "CFTreeGetNextSibling": (b"^{__CFTree=}^{__CFTree=}",),
    "CFMessagePortGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFBagGetCount": (sel32or64(b"l^{__CFBag=}", b"q^{__CFBag=}"),),
    "CFBagRemoveAllValues": (b"v^{__CFBag=}",),
    "CFCharacterSetCreateBitmapRepresentation": (
        b"^{__CFData=}^{__CFAllocator=}^{__CFCharacterSet=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFXMLParserGetDocument": (b"^v^{__CFXMLParser=}",),
    "CFXMLNodeGetTypeCode": (sel32or64(b"l^{__CFXMLNode=}", b"q^{__CFXMLNode=}"),),
    "CFArrayGetValues": (
        sel32or64(b"v^{__CFArray=}{_CFRange=ll}^@", b"v^{__CFArray=}{_CFRange=qq}^@"),
        "",
        {"arguments": {2: {"c_array_length_in_arg": 1, "type_modifier": "o"}}},
    ),
    "CFCharacterSetIsSupersetOfSet": (b"Z^{__CFCharacterSet=}^{__CFCharacterSet=}",),
    "CFRunLoopObserverGetTypeID": (sel32or64(b"L", b"Q"),),
    "CFAbsoluteTimeGetGregorianDate": (
        sel32or64(
            b"{_CFGregorianDate=lccccd}d^{__CFTimeZone=}",
            b"{_CFGregorianDate=iccccd}d^{__CFTimeZone=}",
        ),
    ),
    "CFNotificationCenterRemoveObserver": (
        b"v^{__CFNotificationCenter=}@^{__CFString=}@",
    ),
    "CFCalendarSetTimeZone": (b"v^{__CFCalendar=}^{__CFTimeZone=}",),
    "CFSetCreateMutableCopy": (
        sel32or64(
            b"^{__CFSet=}^{__CFAllocator=}l^{__CFSet=}",
            b"^{__CFSet=}^{__CFAllocator=}q^{__CFSet=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFXMLTreeCreateWithNode": (
        b"^{__CFTree=}^{__CFAllocator=}^{__CFXMLNode=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFRunLoopTimerGetOrder": (
        sel32or64(b"l^{__CFRunLoopTimer=}", b"q^{__CFRunLoopTimer=}"),
    ),
    "CFTreeCreate": (
        sel32or64(
            b"^{__CFTree=}^{__CFAllocator=}^{_CFTreeContext=l^v^?^?^?}",
            b"^{__CFTree=}^{__CFAllocator=}^{_CFTreeContext=q^v^?^?^?}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFPreferencesCopyAppValue": (
        b"@^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CFXMLNodeGetString": (b"^{__CFString=}^{__CFXMLNode=}",),
    "CFSocketCreateWithSocketSignature": (
        sel32or64(
            b"^{__CFSocket=}^{__CFAllocator=}^{_CFSocketSignature=lll^{__CFData=}}L^?^{_CFSocketContext=l^v^?^?^?}",
            b"^{__CFSocket=}^{__CFAllocator=}^{_CFSocketSignature=iii^{__CFData=}}Q^?^{_CFSocketContext=q^v^?^?^?}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__CFSocket=}"},
                            1: {"type": b"Q"},
                            2: {"type": b"^{__CFData=}"},
                            3: {"type": b"^v"},
                            4: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "CFURLEnumeratorCreateForDirectoryURL": (
        sel32or64(
            b"^{__CFURLEnumerator=}^{__CFAllocator=}^{__CFURL=}L^{__CFArray=}",
            b"^{__CFURLEnumerator=}^{__CFAllocator=}^{__CFURL=}Q^{__CFArray=}",
        ),
        "",
        {"retval": {"already_cfretained": True}},
    ),
}
aliases = {
    "CFDateFormatterKey": "CFStringRef",
    "CFNumberFormatterKey": "CFStringRef",
    "CF_TYPED_EXTENSIBLE_ENUM": "_CF_TYPED_EXTENSIBLE_ENUM",
    "CF_EXTENSIBLE_STRING_ENUM": "_CF_TYPED_EXTENSIBLE_ENUM",
    "CF_STRING_ENUM": "_CF_TYPED_ENUM",
    "CFErrorDomain": "CFStringRef",
    "CF_TYPED_ENUM": "_CF_TYPED_ENUM",
    "CFRunLoopMode": "CFStringRef",
    "kCFBookmarkResolutionWithoutMountingMask": "kCFURLBookmarkResolutionWithoutMountingMask",
    "kCFBookmarkResolutionWithoutUIMask": "kCFURLBookmarkResolutionWithoutUIMask",
    "CFCalendarIdentifier": "CFStringRef",
    "kCFFileSecurityRemoveACL": "_FILESEC_REMOVE_ACL",
    "CFXMLTreeRef": "CFTreeRef",
    "CFStreamPropertyKey": "CFStringRef",
    "CFLocaleKey": "CFStringRef",
    "CFNotificationName": "CFStringRef",
    "CFLocaleIdentifier": "CFStringRef",
}
cftypes = [
    ("CFAllocatorRef", b"^{__CFAllocator=}", "CFAllocatorGetTypeID", None),
    ("CFArrayRef", b"^{__CFArray=}", "CFArrayGetTypeID", "NSArray"),
    (
        "CFAttributedStringRef",
        b"^{__CFAttributedString=}",
        "CFAttributedStringGetTypeID",
        "__NSCFAttributedString,NSCFAttributedString",
    ),
    ("CFBagRef", b"^{__CFBag=}", "CFBagGetTypeID", None),
    ("CFBinaryHeapRef", b"^{__CFBinaryHeap=}", "CFBinaryHeapGetTypeID", None),
    ("CFBitVectorRef", b"^{__CFBitVector=}", "CFBitVectorGetTypeID", None),
    (
        "CFBooleanRef",
        b"^{__CFBoolean=}",
        "CFBooleanGetTypeID",
        "__NSCFBoolean,NSCFBoolean",
    ),
    ("CFBundleRef", b"^{__CFBundle=}", "CFBundleGetTypeID", None),
    (
        "CFCalendarRef",
        b"^{__CFCalendar=}",
        "CFCalendarGetTypeID",
        "__NSCFCalendar,NSCFCalendar",
    ),
    (
        "CFCharacterSetRef",
        b"^{__CFCharacterSet=}",
        "CFCharacterSetGetTypeID",
        "__NSCFCharacterSet,NSCFCharacterSet",
    ),
    ("CFDataRef", b"^{__CFData=}", "CFDataGetTypeID", "__NSCFData,NSCFData"),
    ("CFDateFormatterRef", b"^{__CFDateFormatter=}", "CFDateFormatterGetTypeID", None),
    ("CFDateRef", b"^{__CFDate=}", "CFDateGetTypeID", "__NSCFDate,NSCFDate,__NSDate"),
    ("CFDictionaryRef", b"^{__CFDictionary=}", "CFDictionaryGetTypeID", "NSDictionary"),
    ("CFErrorRef", b"^{__CFError=}", "CFErrorGetTypeID", "__NSCFError,NSCFError"),
    (
        "CFFileDescriptorRef",
        b"^{__CFFileDescriptor=}",
        "CFFileDescriptorGetTypeID",
        None,
    ),
    (
        "CFFileSecurityRef",
        b"^{__CFFileSecurity=}",
        "CFFileSecurityGetTypeID",
        "__NSFileSecurity",
    ),
    ("CFLocaleRef", b"^{__CFLocale=}", "CFLocaleGetTypeID", "__NSCFLocale,NSCFLocale"),
    ("CFMachPortRef", b"^{__CFMachPort=}", "CFMachPortGetTypeID", "NSMachPort"),
    ("CFMessagePortRef", b"^{__CFMessagePort=}", "CFMessagePortGetTypeID", None),
    ("CFMutableArrayRef", b"^{__CFArray=}", "CFArrayGetTypeID", "NSMutableArray"),
    (
        "CFMutableAttributedStringRef",
        b"^{__CFAttributedString=}",
        "CFAttributedStringGetTypeID",
        "__NSCFAttributedString,NSCFAttributedString",
    ),
    ("CFMutableBagRef", b"^{__CFBag=}", "CFBagGetTypeID", None),
    ("CFMutableBitVectorRef", b"^{__CFBitVector=}", "CFBitVectorGetTypeID", None),
    (
        "CFMutableCharacterSetRef",
        b"^{__CFCharacterSet=}",
        "CFCharacterSetGetTypeID",
        None,
    ),
    ("CFMutableDataRef", b"^{__CFData=}", "CFDataGetTypeID", "NSMutableData"),
    (
        "CFMutableDictionaryRef",
        b"^{__CFDictionary=}",
        "CFDictionaryGetTypeID",
        "NSMutableDictionary",
    ),
    ("CFMutableSetRef", b"^{__CFSet=}", "CFSetGetTypeID", "NSMutableSet"),
    ("CFMutableStringRef", b"^{__CFString=}", "CFStringGetTypeID", None),
    (
        "CFNotificationCenterRef",
        b"^{__CFNotificationCenter=}",
        "CFNotificationCenterGetTypeID",
        None,
    ),
    ("CFNullRef", b"^{__CFNull=}", "CFNullGetTypeID", "NSNull"),
    (
        "CFNumberFormatterRef",
        b"^{__CFNumberFormatter=}",
        "CFNumberFormatterGetTypeID",
        None,
    ),
    ("CFNumberRef", b"^{__CFNumber=}", "CFNumberGetTypeID", "__NSCFNumber,NSCFNumber"),
    (
        "CFPlugInInstanceRef",
        b"^{__CFPlugInInstance=}",
        "CFPlugInInstanceGetTypeID",
        None,
    ),
    (
        "CFReadStreamRef",
        b"^{__CFReadStream=}",
        "CFReadStreamGetTypeID",
        "__NSCFInputStream,NSCFInputStream",
    ),
    (
        "CFRunLoopObserverRef",
        b"^{__CFRunLoopObserver=}",
        "CFRunLoopObserverGetTypeID",
        None,
    ),
    ("CFRunLoopRef", b"^{__CFRunLoop=}", "CFRunLoopGetTypeID", None),
    ("CFRunLoopSourceRef", b"^{__CFRunLoopSource=}", "CFRunLoopSourceGetTypeID", None),
    (
        "CFRunLoopTimerRef",
        b"^{__CFRunLoopTimer=}",
        "CFRunLoopTimerGetTypeID",
        "__NSCFTimer,NSCFTimer",
    ),
    ("CFSetRef", b"^{__CFSet=}", "CFSetGetTypeID", "NSSet"),
    ("CFSocketRef", b"^{__CFSocket=}", "CFSocketGetTypeID", None),
    ("CFStringRef", b"^{__CFString=}", "CFStringGetTypeID", "NSString"),
    (
        "CFStringTokenizerRef",
        b"^{__CFStringTokenizer=}",
        "CFStringTokenizerGetTypeID",
        None,
    ),
    ("CFTimeZoneRef", b"^{__CFTimeZone=}", "CFTimeZoneGetTypeID", "NSTimeZone"),
    ("CFTreeRef", b"^{__CFTree=}", "CFTreeGetTypeID", None),
    ("CFURLEnumeratorRef", b"^{__CFURLEnumerator=}", "CFURLEnumeratorGetTypeID", None),
    ("CFURLRef", b"^{__CFURL=}", "CFURLGetTypeID", "NSURL"),
    ("CFUUIDRef", b"^{__CFUUID=}", "CFUUIDGetTypeID", None),
    (
        "CFUserNotificationRef",
        b"^{__CFUserNotification=}",
        "CFUserNotificationGetTypeID",
        None,
    ),
    (
        "CFWriteStreamRef",
        b"^{__CFWriteStream=}",
        "CFWriteStreamGetTypeID",
        "__NSCFOutputStream,NSCFOutputStream",
    ),
    ("CFXMLNodeRef", b"^{__CFXMLNode=}", "CFXMLNodeGetTypeID", None),
    ("CFXMLParserRef", b"^{__CFXMLParser=}", "CFXMLParserGetTypeID", None),
]
expressions = {
    "kCFISO8601DateFormatWithFullTime": "kCFISO8601DateFormatWithTime | kCFISO8601DateFormatWithColonSeparatorInTime | kCFISO8601DateFormatWithTimeZone | kCFISO8601DateFormatWithColonSeparatorInTimeZone",
    "kCFISO8601DateFormatWithFullDate": "kCFISO8601DateFormatWithYear | kCFISO8601DateFormatWithMonth | kCFISO8601DateFormatWithDay | kCFISO8601DateFormatWithDashSeparatorInDate",
    "kCFISO8601DateFormatWithInternetDateTime": "kCFISO8601DateFormatWithFullDate | kCFISO8601DateFormatWithFullTime",
}

# END OF FILE
